<?php
/**
 * Frontend Functions
 *
 * @package photosy
 * @since 1.0
*/

if(!function_exists('photosy_loader')) {
  /*
   * Theme Loader
   * @param string $logo_field
   * @param string $default_url
   * @param string $class
   */
  function photosy_loader($loader_field = '', $default_url = '') {
    if(class_exists('ReduxFramework') && !photosy_get_opt('general-loader-enable-switch')) { return; }
    if (empty($loader_field)) {
      $loader_field = 'general-loader-logo';
    }

    if( photosy_get_opt( $loader_field ) != null ) {
      $loader_array = photosy_get_opt( $loader_field );
    }

    if( (!isset( $loader_array['url'] ) || empty($loader_array['url'])) && empty($default_url)) {
      return;
    }

    if(empty($class)) {
      $class = ' logo vertical-align';
    }

    if( !isset( $loader_array['url'] ) || empty($loader_array['url']) ) {
      $loader_url = $default_url;
    } else {
      $loader_url = $loader_array['url'];
    }
  ?>
    <div class="loader">
     <div class="load-title">
        <img src="<?php echo esc_url($loader_url); ?>" alt="<?php echo esc_attr__('loader', 'photosy'); ?>">
        <div class="load-circle"></div>
     </div>
    </div>
<?php
  }
}

if(!function_exists('photosy_main_menu')) {
  /**
   * Main Menu
   *
   * @since photosy 1.0
  */
  function photosy_main_menu($class = '', $menu_id = 'nav', $nav_menu = 'primary-menu') {
    if ( function_exists('wp_nav_menu') && has_nav_menu( $nav_menu ) ) {
      wp_nav_menu(array(
        'theme_location' => $nav_menu,
        'container'      => false,
        'menu_id'        => $menu_id,
        'menu'           => 'primary-menu',
        'menu_class'     => $class,
        'walker'         => new photosy_menu_widget_walker_nav_menu()
      ));
    } else {
      echo '<ul class="primary-nav-list"><li><a target="_blank" href="'. admin_url('nav-menus.php') .'" class="cell-view no-menu">'. esc_html__( 'You can edit your menu content on the Menus screen in the Appearance section.', 'photosy' ) .'</a></li></ul>';
    }
  }
}

 if( !function_exists('photosy_logo')) {
  /**
   * Theme logo
   * @param string $logo_field
   * @param string $default_url
   * @param string $class
  */
  function photosy_logo($logo_field = '', $default_url = '', $class = '') {

    if (empty($logo_field)) {
      $logo_field = 'logo';
    }

    $logo = '';

    if( photosy_get_opt( $logo_field ) != null ) {
      $logo_array = photosy_get_opt( $logo_field );
    }

    if( (!isset( $logo_array['url'] ) || empty($logo_array['url'])) && empty($default_url)) {
      return;
    }

    if(empty($class)) {
      $class = 'custom-logo-link';
    }

    if( !isset( $logo_array['url'] ) || empty($logo_array['url']) ) {
      $logo_url = $default_url;
    } else {
      $logo_url = $logo_array['url'];
    }

    $width  = photosy_get_opt('logo-width');
    $height = photosy_get_opt('logo-height');

    $width_attr  = (!empty($width)) ? $width:115;
    $height_attr = (!empty($height)) ? $height:30;

    ?>
    <a href="<?php echo esc_url(home_url('/')); ?>" class="<?php echo photosy_sanitize_html_classes($class); ?>"><img class="custom-logo" src="<?php echo esc_url($logo_url); ?>" width="<?php echo esc_attr($width_attr); ?>" height="<?php echo esc_attr($height_attr); ?>" alt="<?php echo esc_attr(get_bloginfo( 'name' )); ?>"></a>
    <?php
  }
}


if ( ! function_exists( 'photosy_comment' ) ) :
/**
 * Comments and pingbacks. Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since make 1.0
 */
function photosy_comment( $comment, $args, $depth ) {
  $GLOBALS['comment'] = $comment;
  switch ( $comment->comment_type ) :
    case 'pingback' :
    case 'trackback' :
      ?>
      <li <?php comment_class('comment'); ?> id="li-comment-<?php comment_ID(); ?>">
        <div class="media-body"><?php esc_html_e( 'Pingback:', 'photosy' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( 'Edit', 'photosy' ), ' ' ); ?></div>
      </li>
      <?php
    break;

    default :
      $class = array('comment_wrap');
      if ($depth > 1) {
        $class[] = 'chaild';
      }
      ?>
      <!-- Comment Item -->
      <li <?php comment_class('comment coment-block'); ?> id="comment-<?php comment_ID(); ?>">

        <div class="comment-body">
          <div class="image">
            <?php echo get_avatar( $comment, 45 ); ?>
          </div>

          <div class="comment-content comm-area">
            <div class="comment-meta comm-title">
              <h6 class="h6"><?php comment_author_link();?></h6>
              <span><?php echo comment_date(get_option('date_format')) ?> at <?php echo comment_date(get_option('time_format')) ?></span>
            </div>

            <div class="simple-text">
              <?php if ( $comment->comment_approved == '0' ) : ?>
                <p><?php esc_html_e( 'Your comment is awaiting moderation.', 'photosy' ); ?></p>
              <?php endif; ?>

              <?php comment_text(); ?>

            </div>

            <div class="reply">
              <?php $reply = get_comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => 2 ) ) );
                if (!empty($reply)): ?>
                  <?php echo wp_kses_post($reply); ?>
                <?php endif;
                edit_comment_link( wp_kses_post( 'Edit', 'photosy' ), '', '' );
              ?>
              <a href="#"><?php echo esc_html__('Share', 'photosy'); ?> <i class="icon-right-open-mini"></i></a>
            </div>

            <!--share comment-->

          </div>
        </div>
      <?php
      break;
  endswitch;
}

endif; // ends check for make_comment()

if (!function_exists('photosy_close_comment')):
/**
 * Close comment
 *
 * @since make 1.0
 */
function photosy_close_comment() { ?>
    </li>
    <!-- End Comment Item -->
<?php }

endif; // ends check for make_close_comment()



if( !function_exists('photosy_get_the_title')) {
  /**
   *
   * Get the Page Title
   * @since 1.0.0
   * @version 1.0.0
   *
  */
  function photosy_get_the_title() {
    $title = '';
    if( is_home() && !is_singular('page') ) :
      $title = esc_html__('Blog','photosy');

    elseif( is_singular() ) :
      $title = get_the_title();

    elseif( is_search() ) :
      global $wp_query;
      $total_results = $wp_query->found_posts;
      $prefix = '';

      if( $total_results == 1 ) {
        $prefix = esc_html__('1 search result for', 'photosy');
      }
      else if( $total_results > 1 ) {
        $prefix = $total_results . ' ' . esc_html__('search results for', 'photosy');
      }
      else {
        $prefix = esc_html__('Search results for', 'photosy');
      }
      $title = get_search_query();

    elseif ( is_category() ) :
      $title = single_cat_title('', false);

    elseif ( is_tag() ) :
      $title = single_tag_title('', false);

    elseif ( is_author() ) :
      $title = wp_kses_post(sprintf( __( 'Author: %s', 'photosy' ), '<span class="vcard">' . get_the_author() . '</span>' ));

    elseif ( is_day() ) :
      $title = wp_kses_post(sprintf( __( 'Day: %s', 'photosy' ), '<span>' . get_the_date() . '</span>' ));

    elseif ( is_month() ) :
      $title = wp_kses_post(sprintf( __( 'Month: %s', 'photosy' ), '<span>' . get_the_date( _x( 'F Y', 'monthly archives date format', 'photosy' ) ) . '</span>' ));

    elseif ( is_year() ) :
      $title = wp_kses_post(sprintf( __( 'Year: %s', 'photosy' ), '<span>' . get_the_date( _x( 'Y', 'yearly archives date format', 'photosy' ) ) . '</span>' ));

    elseif( is_tax() ) :
      $term = get_term_by( 'slug', get_query_var( 'term' ), get_query_var( 'taxonomy' ) );
      $title = $term->name;

    elseif ( is_tax( 'post_format', 'post-format-aside' ) ) :
      $title = esc_html__( 'Asides', 'photosy' );

    elseif ( is_tax( 'post_format', 'post-format-gallery' ) ) :
      $title = esc_html__( 'Galleries', 'photosy');

    elseif ( is_tax( 'post_format', 'post-format-image' ) ) :
      $title = esc_html__( 'Images', 'photosy');

    elseif ( is_tax( 'post_format', 'post-format-video' ) ) :
      $title = esc_html__( 'Videos', 'photosy' );

    elseif ( is_tax( 'post_format', 'post-format-quote' ) ) :
      $title = esc_html__( 'Quotes', 'photosy' );

    elseif ( is_tax( 'post_format', 'post-format-link' ) ) :
      $title = esc_html__( 'Links', 'photosy' );

    elseif ( is_tax( 'post_format', 'post-format-status' ) ) :
      $title = esc_html__( 'Statuses', 'photosy' );

    elseif ( is_tax( 'post_format', 'post-format-audio' ) ) :
      $title = esc_html__( 'Audios', 'photosy' );

    elseif ( is_tax( 'post_format', 'post-format-chat' ) ) :
      $title = esc_html__( 'Chats', 'photosy' );

    elseif( is_404() ) :
      $title = esc_html__( '404', 'photosy' );

    else :
      $title = esc_html__( 'Archives', 'photosy' );
    endif;

    return $title;
  }
}

if(!function_exists('photosy_breadcrumbs')) {
  /**
   * Show breadcrumbs
   *
   * @since photosy 1.0
   */
  function photosy_breadcrumbs() {

    $breadcrumbs = photosy_get_opt('title-wrapper-breadcrumb-enable');

    if(class_exists('ReduxFramework') && !$breadcrumbs) { return; }

    $before      = '<li class="breadcrumbs__item">';
    $after       = '</li>';
    $before_last = '';
    $after_last  = '';
    $separator = '';
    ?>
    <!-- Breadcrumbs -->
    <ul class="breadcrumbs">
      <?php

      if (!is_home()) {

        if(!is_front_page()) {
          echo wp_kses_post($before).'<a href="';
          echo esc_url(home_url('/'));
          echo '" class="breadcrumbs__link">';
          echo __('Home', 'photosy');
          echo '</a>'.$after. $separator .'';
        }

        if (is_single()) {

          $cats = get_the_category();

          if( isset($cats[0]) ) :
            echo wp_kses_post($before.'<a href="'. esc_url(get_category_link( $cats[0]->term_id )) .'">'. $cats[0]->cat_name.'</a>' . $after . $separator);
          endif;

          if (is_single()) {
            echo wp_kses_post($before.$before_last);
            the_title();
            echo wp_kses_post($after_last.$after);
          }
        } elseif( is_category() ) {

          $cats = get_the_category();

          if( isset($cats[0]) ) :
            echo wp_kses_post($before.$before_last.single_cat_title('', false).$after_last.$after);
          endif;

        } elseif (is_page()) {
          global $post;

          if($post->post_parent){
            $anc = get_post_ancestors( $post->ID );
            $title = get_the_title();
            foreach ( $anc as $ancestor ) {
              $output = $before.'<a href="'.esc_url(get_permalink($ancestor)).'" title="'.esc_attr(get_the_title($ancestor)).'"  rel="v:url" property="v:title">'.get_the_title($ancestor).'</a>'.$after.' ' . $separator;
            }
            echo wp_kses_post($output);
            echo wp_kses_post($before.$before_last.$title.$after_last.$after);
          } else {
            echo wp_kses_post($before.$before_last.get_the_title().$after_last.$after);
          }
        }
        elseif (is_tag()) {
          echo wp_kses_post($before.$before_last).single_cat_title('', false).$after_last.$after;

        } elseif (is_day()) {
          echo wp_kses_post($before.$before_last). esc_html__('Archive for', 'photosy').' ';
          the_time('F jS, Y');
          echo wp_kses_post($after_last.$after);

        } elseif (is_month()) {
          echo wp_kses_post($before.$before_last).esc_html__('Archive for', 'photosy').' ';
          the_time('F, Y');
          echo wp_kses_post($after_last.$after);

        } elseif (is_year()) {
          echo wp_kses_post($before.$before_last). esc_html__('Archive for', 'photosy').' ';
          the_time('Y');
          echo wp_kses_post($after_last.$after);

        } elseif (is_author()) {
          echo wp_kses_post($before.$before_last). esc_html__('Author Archive', 'photosy');
          echo wp_kses_post($after_last.$after);

        } elseif (isset($_GET['paged']) && !empty($_GET['paged'])) {
          echo wp_kses_post($before.$before_last).esc_html__('Blog Archives', 'photosy').$after_last.$after;

        } elseif (is_search()) {
          echo wp_kses_post($before.$before_last). esc_html__('Search Results', 'photosy').$after_last.$after;

        }

      } elseif (is_home()) {
        echo wp_kses_post($before.$before_last). esc_html__('Home', 'photosy') .$after_last.$after;
      }
      ?>
    </ul>
    <!-- End Breadcrumbs -->
  <?php }
}

if(!function_exists('photosy_blog_post_format')) {
  /**
   *
   * Post Format
   * @since 1.0.0
   * @version 1.0.0
   *
  */
  function photosy_blog_post_format($is_masonry = false) {
    $post_format = get_post_format();
    $image_size = ($is_masonry) ? 'photosy-square-small':'photosy-medium-hor';
    switch ($post_format) {
      case 'audio':
        $audio_id  = photosy_get_post_opt('post-audio-id');
        if(!empty($audio_id)): ?>
          <div class="sound-item">
            <iframe src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/<?php echo esc_attr($audio_id); ?>&amp;color=ff5500&amp;auto_play=false&amp;hide_related=false&amp;show_comments=true&amp;show_user=true&amp;show_reposts=false"></iframe>
          </div>
        <?php endif;
        break;
      case 'video':
        global $post;
        $img_src     = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), $image_size);
        $post_yt_url = photosy_get_post_opt('post-video-yt-url');
        if(isset($img_src[0]) && !empty($post_yt_url)): ?>
          <div class="video-item">
            <div class="bg" style="background-image:url(<?php echo esc_url($img_src[0]); ?>)"></div>
            <a class="nw-play-btn video-open" href="<?php echo esc_url($post_yt_url); ?>?autoplay=1">
              <i class="material-icons">play_arrow</i>
            </a>
            <div class="video-popup">
              <div class="video-popup-overlay"></div>
              <div class="video-popup-content">
                <div class="video-popup-layer"></div>
                <div class="video-popup-container">
                  <div class="video-popup-align">
                    <div class="embed-responsive embed-responsive-16by9">
                      <iframe class="embed-responsive-item" src="about:blank"></iframe>
                    </div>
                  </div>
                  <div class="video-popup-close"></div>
                </div>
              </div>
            </div>
          </div>
        <?php endif;
        break;

      default:
        if(has_post_thumbnail()): ?>
          <div class="image text-center">
            <a href="<?php echo esc_url(get_the_permalink()); ?>"><?php the_post_thumbnail($image_size); ?></a>
          </div>
        <?php endif;
        break;
    }
  }
}

if(!function_exists('photosy_social_share')) {
  /**
   *
   * Social Share
   * @since 1.0.0
   * @version 1.0.0
   *
  */
  function photosy_social_share() {
    $social_google  = photosy_get_opt('single-social-google');
    $social_fb      = photosy_get_opt('single-social-fb');
    $social_twitter = photosy_get_opt('single-social-twitter');
  ?>

    <div class="share">
      <?php if($social_google || !class_exists('ReduxFramework')): ?>
        <a href="https://plus.google.com/share?url=<?php echo esc_url(get_the_permalink()); ?>"><img src="<?php echo get_theme_file_uri('assets/img/share_1.png'); ?>" alt="<?php echo esc_attr__('googleplus', 'photosy'); ?>" class="resp-img"></a>
      <?php endif; ?>
      <?php if($social_fb || !class_exists('ReduxFramework')): ?>
        <a href="https://www.facebook.com/sharer/sharer.php?u=<?php echo esc_url(get_the_permalink()); ?>"><img src="<?php echo get_theme_file_uri('assets/img/share_2.png'); ?>" alt="<?php echo esc_attr__('facebook', 'photosy'); ?>" class="resp-img"></a>
      <?php endif; ?>
      <?php if($social_twitter || !class_exists('ReduxFramework')): ?>
        <a href="https://twitter.com/home?status=<?php echo esc_url(get_the_permalink()); ?>"><img src="<?php echo get_theme_file_uri('assets/img/share_3.png'); ?>" alt="<?php echo esc_attr__('twitter', 'photosy'); ?>" class="resp-img"></a>
      <?php endif; ?>
    </div>
    <?php
  }
}

if(!function_exists('photosy_social_links')) {
  /**
   * Get Social Icons links
   *
   * @param type $terms
   * @return boolean
   */
  function photosy_social_links($pattern = '%s', $category = '', $show_items = false) {
    if(!photosy_get_opt('footer-enable-social-icons')) { return; }
    $args = array(
      'posts_per_page' => -1,
      'offset'          => 0,
      'orderby'         => 'menu_order',
      'order'           => 'ASC',
      'post_type'       => 'social-site',
      'post_status'     => 'publish'
    );

    if (!empty($category)) {
      $args['tax_query'] = array(
        array(
          'taxonomy' => 'social-site-category',
          'field'    => 'id',
          'terms'    => $category,
        ),
      );
    }

    $list_html     = ($show_items) ? '<li>':'';
    $end_list_html = ($show_items) ? '</li>':'';

    $custom_query = new WP_Query( $args );
    if ( $custom_query->have_posts() ):

      $found_posts = $custom_query->found_posts;
      echo ($show_items) ? '<ul>':'';
      while ( $custom_query -> have_posts() ) :
        $custom_query -> the_post();
        echo sprintf($pattern, $list_html.'<a href="'.esc_url(get_the_title()).'"><i class="fa '.esc_attr(photosy_get_post_opt('icon')).'"></i></a>'.$end_list_html);
      endwhile; // end of the loop.
      echo ($show_items) ? '</ul>':'';
    endif;
    wp_reset_postdata();
  }
}

if(!function_exists('photosy_accent_css')) {
  /**
   * Get Social Icons links
   *
   * @param type $terms
   * @return boolean
  */
  function photosy_accent_css() {
    $output = '';
    $footer_logo_width = photosy_get_opt('footer-logo-width');
    $footer_logo_height = photosy_get_opt('footer-logo-height');
    $customize = (!empty($footer_logo_height) || !empty($footer_logo_width)) ? true:false;

    $output = '';

    if($customize) {

      $output .= (!empty($footer_logo_width) || !empty($footer_logo_height)) ? '.footer-logo {':'';
      $output .=  ($footer_logo_width) ? 'max-width:'.esc_attr($footer_logo_width).';':'';
      $output .=  ($footer_logo_height) ? 'height:'.esc_attr($footer_logo_height).';':'';
      $output .= (!empty($footer_logo_width) || !empty($header_logo_height)) ? '}':'';
    }

    return $output;
  }
}

if(!function_exists('photosy_top_margin')) {
  /**
   * photosy_top_margin
   *
   * @param type $terms
   * @return boolean
  */
  function photosy_top_margin($default) {
    $page_top_margin = photosy_get_opt('page-top-margin');
    if($page_top_margin == 'no-margin') { return; }
    $page_top_margin = (empty($page_top_margin) || !class_exists('ReduxFramework')) ? $default:$page_top_margin;
    $output = '<div class="marg-lg-b'.$page_top_margin.' marg-md-b60 marg-xs-b30"></div>';
    return $output;
  }
}

if(!function_exists('photosy_bottom_margin')) {
  /**
   * photosy_bottom_margin
   *
   * @param type $terms
   * @return boolean
  */
  function photosy_bottom_margin($default) {
    $page_bottom_margin = photosy_get_opt('page-bottom-margin');
    if($page_bottom_margin == 'no-margin') { return; }
    $page_bottom_margin = (empty($page_bottom_margin) || !class_exists('ReduxFramework')) ? $default:$page_bottom_margin;
    $output = '<div class="marg-lg-b'.$page_bottom_margin.' marg-md-b60 marg-xs-b30"></div>';
    return $output;
  }
}

if(!function_exists('photosy_footer_columns')) {
  /**
   * Footer Columns
   * @param type $type
   * @return array
  */
  function photosy_footer_columns() {
    $footer_columns = photosy_get_opt('footer-column');
    switch ($footer_columns) {
      case '1':
        $col_class = 'col-md-12 col-sm-12';
        break;
      case '2':
        $col_class = 'col-md-6 col-sm-6';
        break;
      case '3':
        $col_class = 'col-md-4 col-sm-6';
        break;
      case '4':
      default:
        $col_class = 'col-md-3 col-sm-6';
        break;
    }
    for($i = 1; $i < $footer_columns + 1; $i++) { ?>
      <div class="<?php echo esc_attr($col_class .' col-'.$i); ?>">
        <?php if (is_active_sidebar( photosy_get_custom_sidebar('footer-'.$i, 'footer-sidebar-'.$i) )): ?>
          <?php dynamic_sidebar( photosy_get_custom_sidebar('footer-'.$i, 'footer-sidebar-'.$i) ); ?>
        <?php endif; ?>
      </div>
    <?php }
  }
}
