<?php
/**
 * Helper Functions
 *
 * @package photosy
 * @since 1.0
*/
if( ! function_exists( 'photosy_inline_id' ) ) {
  /**
   *
   * Inline ID Parser
   *
   * @since 1.0.0
   * @version 1.0.0
   *
   */
  function photosy_inline_id( $id = '' ) {
    echo photosy_get_inline_id( $id );
  }
}

if( ! function_exists( 'photosy_get_inline_id' ) ) {
  /**
   *
   * Inline ID Parser
   *
   * @since 1.0.0
   * @version 1.0.0
   *
   */
  function photosy_get_inline_id( $id = '' ) {
    return ( $id != '' ) ? ' id="'. esc_attr( $id ) .'"' : '';
  }
}

if( ! function_exists( 'photosy_inline_class' ) ) {
  /**
   *
   * Inline Class Parser
   *
   * @since 1.0.0
   * @version 1.0.0
   *
   */
  function photosy_inline_class( $atts = array(), $include_class = true ) {
    echo photosy_get_inline_class( $atts, $include_class = true );
  }
}

if( ! function_exists( 'photosy_get_inline_class' ) ) {
  /**
   *
   * Inline Class Parser
   *
   * @since 1.0.0
   * @version 1.0.0
   *
   */
  function photosy_get_inline_class( $atts, $include_class = true ) {

    if( empty( $atts ) ) { return; }

    $output = '';
    $class  = array();

    if( is_array( $atts ) ) {
      foreach( $atts as $key => $value ) {
        if( is_numeric( $key ) ) {
          $class = explode( ' ', $value );
        } else if( $value ) {
          $class[] = $key;
        } else if( $key === 'custom') {
          $class[] = $value;
        }

      }
    } else {
      $class = explode( ' ', $atts );
    }

    if( ! empty( $class ) ) {

      $classes = join( ' ', sanitize_html_class( $class ) );
      $output  = ( $include_class ) ? ' class="'. $classes .'"' : ' '. $classes;

    }

    return $output;

  }
}

if( ! function_exists( 'photosy_inline_style' ) ) {
  /**
   *
   * Inline Style Parser
   *
   * @since 1.0.0
   * @version 1.0.0
   *
   */
  function photosy_inline_style( $atts = array() ) {
    echo photosy_get_inline_style( $atts );
  }
}
if( ! function_exists( 'photosy_get_inline_style' ) ) {
  /**
   *
   * Inline Style Parser
   *
   * @since 1.0.0
   * @version 1.0.0
   *
   */
  function photosy_get_inline_style( $atts = array() ) {

    if( empty( $atts ) ) { return; }

    $style = '';

    foreach( $atts as $key => $value ) {

      if( isset( $value ) && $value != '' && $key != 'custom' ) {
        $style .= $key .':'. $value .';';
      }

      if( $key == 'custom' ) {
        $style .= $value;
      }

    }

    $style = ( ! empty( $style ) ) ? ' style="'. esc_attr( $style ) .'"' : '';

    return $style;

  }
}

if( ! function_exists( 'photosy_inline_html5_data' ) ) {
  /**
   *
   * Inline HTML5 Data Parser
   *
   * @since 1.0.0
   * @version 1.0.0
   *
   */
  function photosy_inline_html5_data( $atts = array() ) {
    echo photosy_get_inline_html5_data( $atts );
  }
}

if( ! function_exists( 'photosy_get_inline_html5_data' ) ) {
  /**
   *
   * Inline HTML5 Data Parser
   *
   * @since 1.0.0
   * @version 1.0.0
   *
   */
  function photosy_get_inline_html5_data( $atts = array() ) {

    if( empty( $atts ) ) { return; }

    $data = array();

    foreach( $atts as $key => $value ) {

      if( isset( $value ) && (string) $value != '' && $key != 'custom' ) {
        $data[] = 'data-'. esc_attr( $key ) .'="'. esc_attr( $value ) .'"';
      }

      if( $key == 'custom' ) {
        $data[] = $value;
      }

    }

    return ( ! empty( $data ) ) ? join( ' ', $data ) : '';

  }
}

if( ! function_exists( 'photosy_inline_html_tag' ) ) {
  /**
   *
   * Inline HTML Tag Parser
   *
   * @since 1.0.0
   * @version 1.0.0
   *
   */
  function photosy_inline_html_tag( $atts = array() ) {
    echo photosy_get_inline_html_tag( $atts );
  }
}
if( ! function_exists( 'photosy_get_inline_html_tag' ) ) {
  /**
   *
   * Inline HTML Tag Parser
   *
   * @since 1.0.0
   * @version 1.0.0
   *
   */
  function photosy_get_inline_html_tag( $atts = array() ) {

    if( empty( $atts ) ) { return; }

    $tag = '';

    foreach( $atts as $key => $value ) {

      if( isset( $value ) && $value != '' && $key != 'custom' ) {
        $tag .= ' '. $key .'="'. esc_attr( $value ) .'"';
      }

      if( $key == 'custom' ) {
        $tag .= ' '. $value;
      }

    }

    return ( ! empty( $tag ) ) ? $tag : '';

  }
}


if ( ! function_exists( 'photosy_post_excerpt' ) ) {
  /**
   *
   * Blog Excerpt Read More
   * @since 1.7.0
   * @version 1.0.0
   *
   */
  function photosy_post_excerpt( $limit = '', $content = '' ) {
    $limit   = ( empty($limit)) ? 20:$limit;
    $content = (empty($content)) ? get_the_excerpt():$content;
    $content = strip_shortcodes( $content );
    $content = str_replace( ']]>', ']]&gt;', $content );
    $content = strip_tags( $content );
    $words   = explode( ' ', $content, $limit + 1 );

    if( count( $words ) > $limit ) {

      array_pop( $words );
      $content  = implode( ' ', $words );
      $content .= ' ...';

    }

    return $content;

  }
}

if ( ! function_exists( 'photosy_sanitize_html_classes' ) && function_exists( 'sanitize_html_class' ) ) {
  /**
  *
  * @return none
  * @param  class
  * multiple class sanitization
  *
  **/
  function photosy_sanitize_html_classes( $class, $fallback = null ) {

    if ( is_string( $class ) ) {
      $class = explode(" ", $class);
    }

    if ( is_array( $class ) && count( $class ) > 0 ) {
      $class = array_map("sanitize_html_class", $class);
      return implode(" ", $class);
    }
    else {
      return sanitize_html_class( $class, $fallback );
    }
  }
}

if ( ! function_exists( 'photosy_paging_nav' ) ) {
  /**
   *
   * Pagination
   * @since 1.0.0
   * @version 1.0.0
   *
   */
  function photosy_paging_nav( $max_num_pages = false) {

    $pagination = photosy_get_opt('blog-post-pagination');

    if(!$pagination && class_exists('ReduxFramework')) { return; }

    if (get_query_var('paged')) {
      $paged = get_query_var('paged');
    } elseif (get_query_var('page')) {
      $paged = get_query_var('page');
    } else {
      $paged = 1;
    }

    if ($max_num_pages === false) {
      global $wp_query;
      $max_num_pages = $wp_query->max_num_pages;
    }

    $big = 999999999; 

    $links = paginate_links( array(
      'base'      => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
      'format'    => '?paged=%#%',
      'current'   => $paged,
      'total'     => $max_num_pages,
      'prev_next' => false,
      'end_size'  => 1,
      'mid_size'  => 2,
      'type'      => 'plain',
    ) );

    if (!empty($links)): ?>
      <div class="blog-nav wow zoomIn" data-wow-delay="0.4s">
        <?php echo wp_kses_post($links); ?>
      </div>
    <?php endif;

  }
}

if(!function_exists('photosy_header_template')) {
  /**
   * Photosy Header Template
   * @since photosy 1.0
  */
  function photosy_header_template($layout) {
    $header_on_off = photosy_get_opt('header-enable-switch');
    if(!$header_on_off && class_exists('ReduxFramework')) { return; }
    switch ($layout) {
      case 'header-style5':
        get_template_part('theme/inc/header/header-style5');
        break;
      case 'header-style4':
        get_template_part('theme/inc/header/header-style4');
        break;
      case 'header-style3':
        get_template_part('theme/inc/header/header-style3');
        break;
      case 'header-style2':
        get_template_part('theme/inc/header/header-style2');
        break;
      case 'header-style1':
      default:
        get_template_part('theme/inc/header/header-style1');
        break;
    }
  }
}

if(!function_exists('photosy_footer_template')) {
  /**
   * photosy_footer_template
   * @since photosy 1.0
  */
  function photosy_footer_template($layout) {
    $footer_on_off = photosy_get_opt('footer-enable-switch');
    if(!$footer_on_off && class_exists('ReduxFramework')) { return; }
    switch ($layout) {
      case 'footer-style7':
        get_template_part('theme/inc/footer/footer-style7');
        break;
      case 'footer-style6':
        get_template_part('theme/inc/footer/footer-style6');
        break;
      case 'footer-style5':
        get_template_part('theme/inc/footer/footer-style5');
        break;
      case 'footer-style4':
        get_template_part('theme/inc/footer/footer-style4');
        break;
      case 'footer-style3':
        get_template_part('theme/inc/footer/footer-style3');
        break;
      case 'footer-style2':
        get_template_part('theme/inc/footer/footer-style2');
        break;
      case 'footer-style1':
      default:
        get_template_part('theme/inc/footer/footer-style1');
        break;
    }
  }
}

if(!function_exists('photosy_title_wrapper_template')) {
  /**
   * Photosy Title Wrapper Template
   * @since photosy 1.0
  */
  function photosy_title_wrapper_template($layout) {
    $title_wrapper = 'yes';
    if( $title_wrapper === 'yes' ) {
      switch ($layout) {
        case 'default':
        default:
          get_template_part('theme/inc/title-wrapper/default');
          break;
      }
    }
  }
}

if(!function_exists('photosy_blog_single_template')) {
  /**
   * Photosy Blog Single Template
   * @since photosy 1.0
  */
  function photosy_blog_single_template($layout) {
    switch ($layout) {
      case 'default':
      default:
        get_template_part('theme/inc/blog-single/default');
        break;
    }
  }
}

if(!function_exists('photosy_fonts_url')) {
  /**
   * Load Google Font
   *
   * @param type $terms
   * @return boolean
   */
  function photosy_fonts_url() {
    $fonts_url = '';
    $arimo = _x( 'on', 'Arimo font: on or off', 'photosy' );

    if ( 'off' !== $arimo ) {
      $font_families[] = 'Arimo:400,700';
    }

    $query_args = array('family' => urlencode( implode( '|', $font_families ) ), 'subset' => urlencode( 'latin,latin-ext' ));
    $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
    
    return esc_url_raw( $fonts_url );
  }
}

if(!function_exists('photosy_material_font_icon')) {
  /**
   * Load Material Icon
   *
   * @param type $terms
   * @return boolean
  */
  function photosy_material_font_icon() {
    $fonts_url = '';

    $material_icons = _x( 'on', 'Material Icons: on or off', 'photosy' );

    if ( 'off' !== $material_icons ) {
      $font_families = array();

      if ( 'off' !== $material_icons ) {
        $font_families[] = 'Material Icons';
      }

      $query_args = array('family' => urlencode( implode( '|', $font_families ) ));
      $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/icon' );
    }

    return esc_url_raw( $fonts_url );
  }
}

if ( ! function_exists( 'photosy_sanitize_html_classes' ) && function_exists( 'sanitize_html_class' ) ) {
  /**
  *
  * @return none
  * @param  class
  * multiple class sanitization
  *
  **/
  function photosy_sanitize_html_classes( $class, $fallback = null ) {

    if ( is_string( $class ) ) {
      $class = explode(" ", $class);
    }

    if ( is_array( $class ) && count( $class ) > 0 ) {
      $class = array_map("sanitize_html_class", $class);
      return implode(" ", $class);
    }
    else {
      return sanitize_html_class( $class, $fallback );
    }
  }
}

if ( ! function_exists( 'photosy_auto_post_excerpt' ) ) {
  /**
   *
   * Blog Excerpt Read More
   * @since 1.7.0
   * @version 1.0.0
   *
   */
  function photosy_auto_post_excerpt( $limit = '' ) {
    $limit   = ( empty($limit)) ? 20:$limit;
    $content = get_the_excerpt();
    $content = strip_shortcodes( $content );
    $content = str_replace( ']]>', ']]&gt;', $content );
    $content = strip_tags( $content );
    $words   = explode( ' ', $content, $limit + 1 );

    if( count( $words ) > $limit ) {

      array_pop( $words );
      $content  = implode( ' ', $words );
      $content .= ' &hellip;';

    }

    return $content;

  }
}

if ( ! function_exists( 'sanitize_html_classes' ) && function_exists( 'sanitize_html_class' ) ) {
  /**
  *
  * @return none
  * @param  class
  * multiple class sanitization
  *
  **/
  function sanitize_html_classes( $class, $fallback = null ) {

    // Explode it, if it's a string
    if ( is_string( $class ) ) {
      $class = explode(" ", $class);
    }

    if ( is_array( $class ) && count( $class ) > 0 ) {
      $class = array_map("sanitize_html_class", $class);
      return implode(" ", $class);
    }
    else {
      return sanitize_html_class( $class, $fallback );
    }
  }
}

if(!function_exists('photosy_get_custom_sidebars_list')) {
  /**
   * Get custom sidebars list
   * @return array
   */
  function photosy_get_custom_sidebars_list($add_default = true) {

    $sidebars = array();
    if ($add_default) {
      $sidebars['default'] = esc_html__('Default', 'photosy');
    }

    $options = get_option('photosy_theme_options');

    if (!isset($options['custom-sidebars']) || !is_array($options['custom-sidebars'])) {
      return $sidebars;
    }

    if (is_array($options['custom-sidebars'])) {
      foreach ($options['custom-sidebars'] as $sidebar) {
        $sidebars[sanitize_title ( $sidebar )] = $sidebar;
      }
    }

    return $sidebars;
  }
}

if( !function_exists('photosy_get_custom_sidebar')) {
  /**
   * Get custom sidebar, returns $default if custom sidebar is not defined
   * @param string $default
   * @param string $sidebar_option_field
   * @return string
   */
  function photosy_get_custom_sidebar($default = '', $sidebar_option_field = 'sidebar') {

    $sidebar = photosy_get_opt($sidebar_option_field);

    if ($sidebar != 'default' && !empty($sidebar)) {
      return $sidebar;
    }
    return $default;
  }
}

if(!function_exists('photosy_sidebar_position')) {
  /**
   * Return page layout
   * @param type $type
   * @return array
   */
  function photosy_sidebar_position() {
    $sidebar_details = array();
    if(is_singular('post')) {
      $sidebar_details['layout']       = photosy_get_opt('blog-single-layout');
      $sidebar_details['sidebar-name'] = 'blog-sidebar';
    } elseif(is_archive()) {
      $sidebar_details['layout']       = photosy_get_opt('archive-layout');
      $sidebar_details['sidebar-name'] = 'archive-sidebar';
    } elseif(is_search()) {
      $sidebar_details['layout']       = photosy_get_opt('search-layout');
      $sidebar_details['sidebar-name'] = 'search-sidebar';
    } else {
      $sidebar_details['layout'] = photosy_get_opt('main-layout');
      $sidebar_details['sidebar-name'] = 'sidebar';
    }
    return $sidebar_details;
  }
}

if(!function_exists('photosy_blog_post_column')) {
  /**
   * Return bol column class
   * @param type $type
   * @return array
   */
  function photosy_blog_post_column() {
    $sidebar_details = photosy_sidebar_position();
    $col_class = ($sidebar_details['layout'] != 'default' && !empty($sidebar_details['layout'])) ? 'wh-50 item':'wh-30 item';
    return $col_class;
  }
}

if ( ! function_exists( 'photosy_element_values_page' ) ) {
  /**
   *
   * element values post, page, categories
   * @since 1.0.0
   * @version 1.0.0
   *
   */
  function photosy_element_values_page(  $type = '', $query_args = array() ) {

    $options = array();

    switch( $type ) {

      case 'pages':
      case 'page':
      $pages = get_pages( $query_args );

      if ( !empty($pages) ) {
        foreach ( $pages as $page ) {
          $options[$page->post_title] = $page->ID;
        }
      }
      break;

      case 'posts':
      case 'post':
      $posts = get_posts( $query_args );

      if ( !empty($posts) ) {
        foreach ( $posts as $post ) {
          $options[$post->post_title] = lcfirst($post->ID);
        }
      }
      break;

      case 'tags':
      case 'tag':

    if (isset($query_args['taxonomies']) && taxonomy_exists($query_args['taxonomies'])) {
    $tags = get_terms( $query_args['taxonomies'], $query_args['args'] );
      if ( !is_wp_error($tags) && !empty($tags) ) {
      foreach ( $tags as $tag ) {
        $options[$tag->name] = $tag->term_id;
      }
    }
    }
      break;

      case 'categories':
      case 'category':

    if (isset($query_args['taxonomy']) && taxonomy_exists($query_args['taxonomy'])) {
      $categories = get_categories( $query_args );
      if ( !empty($categories) && is_array($categories) ) {
        foreach ( $categories as $category ) {
         $options[$category->name] = $category->slug;
        }
      }
    }
      break;

      case 'custom':
      case 'callback':

      if( is_callable( $query_args['function'] ) ) {
        $options = call_user_func( $query_args['function'], $query_args['args'] );
      }

      break;

    }

    return $options;

  }
}

if(!function_exists('photosy_get_space_array')) {
  /**
   * Get space array
   * @param type $type
   * @return array
  */
  function photosy_get_space_array() {
    $space_array = array('no-margin' => 'No Margin');
    for($i = 5; $i < 215;) {
      $space_array[$i] = $i;
      $i = $i + 5;
    }
    return $space_array;
  }
}

if(!function_exists('photosy_get_custom_term_values')) {
  /**
   * Get custom term values array
   * @param type $type
   * @return type
   */
  function photosy_get_custom_term_values($type) {
    $items = array();
    $terms = get_terms($type, array('orderby' => 'name'));
    if (is_array($terms) && !is_wp_error($terms)) {
      foreach ($terms as $term) {
        $items[$term->name] = $term->slug;
      }
    }
    return $items;
  }
}
