<?php
/**
 * Action Hooks.
 *
 * @package photosy
 * @since 1.0
*/
if( !function_exists('photost_after_setup')) {

  function photost_after_setup() {

    add_image_size('photosy-large-hor',       1140, 585,  true );
    add_image_size('photosy-medium-hor',      768,  255,  true ); // blog featured image
    add_image_size('photosy-small',           288,  192,  true );
    add_image_size('photosy-small-medium',    292,  335,  true );
    add_image_size('photosy-small-ver',       389,  400,  true );
    add_image_size('photosy-small-ver-long',  288,  495,  true );

    add_image_size('photosy-square-small',           360,  360, true);
    add_image_size('photosy-square-medium',          750,  750, true);
    add_image_size('photosy-rectangle-medium',       750,  360, true);
    add_image_size('photosy-rectangle-medium-alt',   1600, 1100, true);
    add_image_size('photosy-rectangle-large',        1140, 360, true);

    define('PHOTOSY_THEME_ACTIVATED', true);

    add_theme_support('post-thumbnails');
    add_theme_support('custom-background');
    add_theme_support('automatic-feed-links' );
    add_theme_support('post-formats', array('video', 'audio') );
    add_theme_support('title-tag');
    add_theme_support('wp-block-styles');
    add_theme_support('responsive-embeds');

    load_theme_textdomain('photosy', get_theme_file_uri('languages'));

    register_nav_menus (array(
      'primary-menu' => esc_html__( 'Main Menu', 'photosy' ),
    ) );
  }
  add_action( 'after_setup_theme', 'photost_after_setup' );
}

/**
* @return null
* @param none
* editor style
**/
if(!function_exists('photosy_theme_editor_style')) {
  function photosy_theme_editor_style() {
    add_editor_style( 'custom-editor-style.css' );
  }
  add_action( 'admin_init', 'photosy_theme_editor_style' );
}

if(!function_exists('photosy_enqueue_scripts')) {
  function photosy_enqueue_scripts() {
    if(( is_admin())) { return; }

    if (is_singular()) { wp_enqueue_script( 'comment-reply' ); }

    wp_enqueue_script('isotope',                    get_theme_file_uri('assets/js/isotope.pkg.min.js'),       array('jquery'), '1.0.0', true);
    wp_enqueue_script('lightgallery',               get_theme_file_uri('assets/js/lightgallery.min.js'),      array('jquery'), '1.0.0', true);
    wp_enqueue_script('swiper',                     get_theme_file_uri('assets/js/idangerous.swiper.min.js'), array('jquery'), '1.0.0', true);
    wp_enqueue_script('lazyload',                   get_theme_file_uri('assets/js/jquery.lazyload.min.js'),   array('jquery'), '1.0.0', true);
    wp_enqueue_script('photosy-all',                get_theme_file_uri('assets/js/all.js'),                   array('jquery'), '1.0.0', true);

    wp_register_script('multiscroll',               get_theme_file_uri('assets/js/jquery.multiscroll.js'),   array('jquery'), '1.0.0', true);
    wp_register_script('multiscroll-responsive',    get_theme_file_uri('assets/js/multiscroll.responsiveExpand.min.js'),   array('jquery'), '1.0.0', true);
    wp_register_script('easing',                    get_theme_file_uri('assets/js/jquery.easings.min.js'),   array('jquery'), '1.0.0', true);

    wp_enqueue_style('bootstrap',      get_theme_file_uri('assets/css/bootstrap.min.css'),        null, '1.0.0');
    wp_enqueue_style('material-icon',  photosy_material_font_icon(),                              null, '1.0.0');
    wp_enqueue_style('photosy-font',   photosy_fonts_url(),                                       null, '1.0.0');
    wp_enqueue_style('swiper',         get_theme_file_uri('assets/css/idangerous.swiper.css'),    null, '1.0.0');
    wp_enqueue_style('foneawesome',    get_theme_file_uri('assets/css/font-awesome.min.css'),     null, '1.0.0');
    wp_enqueue_style('lg',             get_theme_file_uri('assets/css/lightgallery.min.css'),     null, '1.0.0');
    wp_enqueue_style('lg-animation',   get_theme_file_uri('assets/css/lg-transitions.min.css'),   null, '1.0.0');
    wp_enqueue_style('photosy-style',  get_theme_file_uri('assets/css/style.css'),                null, '1.0.0');
    wp_register_style('multiscroll',   get_theme_file_uri('assets/css/jquery.multiscroll.css'),   null, '1.0.0');

    $accent_code = photosy_accent_css();
    $style = '';
    $style .= (!empty($accent_code)) ? $accent_code:'';

    wp_add_inline_style('photosy-style', $style);

  }
  add_action('wp_enqueue_scripts', 'photosy_enqueue_scripts');
}

if(!function_exists('photosy_set_homepage_menu')) {
  /**
   * Set up homepage and menu
   *
   * @package photosy
   * @since 1.0
   */
  function photosy_set_homepage_menu($demo_active_import, $demo_directory_path) {
    reset( $demo_active_import );
    $current_key = key( $demo_active_import );
    $wbc_menu_array = array(
      'Demo',
    );
    if ( isset( $demo_active_import[$current_key]['directory'] ) && !empty( $demo_active_import[$current_key]['directory'] ) && in_array( $demo_active_import[$current_key]['directory'], $wbc_menu_array ) ) {
      $locations = get_nav_menu_locations();
      $main_menu = get_term_by( 'name', 'Main Menu', 'nav_menu' );

      if (isset($main_menu->term_id)) {
        set_theme_mod( 'nav_menu_locations', array(
          'primary-menu' => $main_menu->term_id,
        ));
      }
    }

    $wbc_home_pages = array(
      'Demo' => 'Home',
    );
    if ( isset( $demo_active_import[$current_key]['directory'] ) && !empty( $demo_active_import[$current_key]['directory'] ) && array_key_exists( $demo_active_import[$current_key]['directory'], $wbc_home_pages ) ) {
      $page = get_page_by_title( $wbc_home_pages[$demo_active_import[$current_key]['directory']] );
      if ( isset( $page->ID ) ) {
        update_option( 'page_on_front', $page->ID );
        update_option( 'show_on_front', 'page' );
      }
    }
  }
  add_action( 'wbc_importer_after_content_import', 'photosy_set_homepage_menu', 10, 2 );
}

if ( !function_exists( 'photosy_after_content_import' ) ) {
  /**
   * Inactive default widgets after import
   *
   * @package photosy
   * @since 1.0
   */
  function photosy_after_content_import( $demo_active_import , $demo_data_directory_path ) {
    $inactive = array();
    $sidebars = wp_get_sidebars_widgets();

    if( isset( $sidebars['wp_inactive_widgets'] ) ) {
      $inactive = $sidebars['wp_inactive_widgets'];
      unset( $sidebars['wp_inactive_widgets'] );
    }

    foreach ( $sidebars as $sidebar => $widgets ) {
      if(is_array($widgets)):
        $inactive = array_merge( $inactive, $widgets );
      endif;
      $sidebars[$sidebar] = array();
    }

    $sidebars['wp_inactive_widgets'] = $inactive;

    wp_set_sidebars_widgets( $sidebars );
  }

  add_action( 'wbc_importer_after_content_import', 'photosy_after_content_import', 10, 2 );
}

if( !function_exists('photosy_register_sidebar') ) {
  /**
  * @return null
  * @param none
  * register widgets
  **/
  function photosy_register_sidebar() {
    register_sidebar(array(
      'id'            => 'main',
      'name'          => 'Main Sidebar',
      'before_widget' => '<div id="%1$s" class="sidebar-item widget %2$s">',
      'after_widget'  => '</div>',
      'before_title'  => '<h5 class="h5 widget-title">',
      'after_title'   => '</h5>',
      'description'   => 'Drag the widgets for main sidebars.'
    ));

    for($i = 1; $i < 5; $i++) {
      register_sidebar(array(
        'id'            => 'footer-'.$i,
        'name'          => esc_html__('Footer Sidebar '.$i, 'photosy'),
        'before_widget' => '<div id="%1$s" class="widget footer-item footer_widget %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h6 class="footer-widget-heading h6">',
        'after_title'   => '</h6>',
        'description'   => 'Drag the widgets for sidebars.'
      ));
    }

    $custom_sidebars = photosy_get_opt('custom-sidebars');
    if (is_array($custom_sidebars)) {
      foreach ($custom_sidebars as $sidebar) {

        if (empty($sidebar)) {
          continue;
        }

        register_sidebar ( array (
          'name'          => $sidebar,
          'id'            => sanitize_title ( $sidebar ),
          'before_widget' => '<div id="%1$s" class="sidebar-item widget %2$s">',
          'after_widget'  => '</div>',
          'before_title'  => '<h5 class="h5 widget-title">',
          'after_title'   => '</h5>',
          'description'   => 'Drag the widgets for custom sidebars.'
        ) );
      }
    }
  }
  add_action( 'widgets_init', 'photosy_register_sidebar' );
}


if(! function_exists('photosy_include_required_plugins')) {
  /**
  * @return null
  * @param none
  * tgm_include
  **/
  function photosy_include_required_plugins() {

    $plugins = array(

      array(
        'name'    => 'Redux Framework',
        'slug'    => 'redux-framework',
        'required'  => true,
      ),

      array(
        'name'               => esc_html__('Contact Form 7', 'photosy'), // The plugin name
        'slug'               => 'contact-form-7', // The plugin slug (typically the folder name)
        'required'           => false, // If false, the plugin is only 'recommended' instead of required
        'version'            => '', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
        'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
        'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
        'external_url'       => '', // If set, overrides default API URL and points to an external URL
      ),
      array(
        'name'               => esc_html__('Dragfy Addons for Elementor', 'photosy'), // The plugin name
        'slug'               => 'dragfy-addons-for-elementor', // The plugin slug (typically the folder name)
        'required'           => true, // If false, the plugin is only 'recommended' instead of required
        'version'            => '', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
        'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
        'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
        'external_url'       => '', // If set, overrides default API URL and points to an external URL
      ),
      array(
        'name'               => esc_html__('Visual Composer', 'photosy'), // The plugin name
        'slug'               => 'js_composer', // The plugin slug (typically the folder name)
        'source'             =>  get_template_directory_uri().'/plugins/js_composer.zip', // The plugin source
        'required'           => true, // If false, the plugin is only 'recommended' instead of required
        'version'            => '5.5.1', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
        'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
        'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
        'external_url'       => '', // If set, overrides default API URL and points to an external URL
      ),
      array(
        'name'               => esc_html__('Photosy Addons', 'photosy'), // The plugin name
        'slug'               => 'photosy-addons', // The plugin slug (typically the folder name)
        'source'             => get_template_directory_uri().'/plugins/photosy-addons.zip', // The plugin source
        'required'           => true, // If false, the plugin is only 'recommended' instead of required
        'version'            => '', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
        'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
        'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
        'external_url'       => '', // If set, overrides default API URL and points to an external URL
      ),
      array(
        'name'               => esc_html__('Redux Addons', 'photosy'), // The plugin name
        'slug'               => 'redux-addons', // The plugin slug (typically the folder name)
        'source'             => get_template_directory_uri().'/plugins/redux-addons.zip', // The plugin source
        'required'           => true, // If false, the plugin is only 'recommended' instead of required
        'version'            => '', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
        'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
        'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
        'external_url'       => '', // If set, overrides default API URL and points to an external URL
      ),
      array(
        'name'               => esc_html__('Newsletter', 'photosy'),
        'slug'               => 'newsletter',
        'required'           => false,
        'force_activation'   => false,
        'force_deactivation' => false,
        'external_url'       => '',
      ),
      array(
        'name'               => esc_html__('Instagram', 'photosy'),
        'slug'               => 'wp-instagram-widget',
        'required'           => false,
        'version'            => '',
        'force_activation'   => false,
        'force_deactivation' => false,
        'external_url'       => '',
      ),
    );

    $config = array(
      'id'           => 'photosy',                   // Unique ID for hashing notices for multiple instances of TGMPA.
      'default_path' => '',                      // Default absolute path to bundled plugins.
      'menu'         => 'tgmpa-install-plugins', // Menu slug.
      'parent_slug'  => 'themes.php',            // Parent menu slug.
      'capability'   => 'edit_theme_options',    // Capability needed to view plugin install page, should be a capability associated with the parent menu used.
      'has_notices'  => true,                    // Show admin notices or not.
      'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
      'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
      'is_automatic' => false,                   // Automatically activate plugins after installation or not.
      'message'      => '',                      // Message to output right before the plugins table.
    );

    tgmpa( $plugins, $config );

  }
  add_action( 'tgmpa_register', 'photosy_include_required_plugins' );
}
