<?php
/**
 * Filter Hooks
 *
 * @package make
 * @since 1.0
 */

if (! function_exists('photosy_wp_title') ) {
  /**
   * Title Filter
   *
   * @package make
   * @since 1.0
   */
  function photosy_wp_title( $title, $sep ) {
    global $paged, $page;

    if ( is_feed() ) {
      return $title;
    } // end if

    // Add the site name.
    $title .= get_bloginfo( 'name' );

    // Add the site description for the home/front page.
    $site_description = get_bloginfo( 'description', 'display' );
    if ( $site_description && ( is_home() || is_front_page() ) ) {
      $title = "$title $sep $site_description";
    } // end if

    // Add a page number if necessary.
    if ( $paged >= 2 || $page >= 2 ) {
      $title = sprintf( __( 'Page %s', 'photosy' ), max( $paged, $page ) ) . " $sep $title";
    } // end if

    return $title;

  } // end rs_wp_title
  add_filter( 'wp_title', 'photosy_wp_title', 10, 2 );
}

if(!function_exists('photosy_upload_svg')) {
  /**
   * Allow xml file to upload
   *
   * @package adios
   * @since 1.0
   */
  function photosy_upload_svg($mimes) {
    $mimes['svg'] = 'image/svg+xml';
    return $mimes;
  }
  add_filter('upload_mimes', 'photosy_upload_svg');
}


if( !function_exists('photosy_body_class')) {
  /**
   * Body Filter Hook
   *
   * @package make
   * @since 1.0
   */
  function photosy_body_class($classes) {
    global $post;
    $classes[] = '';
    $classes[] = photosy_get_opt('header-template');
    $classes[] = 'header-style1';
    $classes[] = isset($post) && has_post_thumbnail($post->ID) ? 'has-featured-image':'no-featured-image';
    return $classes;
  }
  add_filter('body_class', 'photosy_body_class');
}

if(!function_exists('photosy_facebook_post_thumbnail')) {
  /**
   * photosy_facebook_post_thumbnail
   *
   * @package photosy
   * @since 1.0
   */
  function photosy_facebook_post_thumbnail() { 
    $fb_image = wp_get_attachment_image_src(get_post_thumbnail_id( get_the_ID() ), 'photosy-medium');
  ?>
    <meta property="og:image" content="<?php echo esc_url($fb_image[0]); ?>"/>
  <?php
  }
  //add_filter('wp_head', 'photosy_facebook_post_thumbnail');
}


if(!function_exists('luxe_instagram_ul_filter')) {
  /**
   * luxe_instagram_ul_filter
   *
   * @package make
   * @since 1.0
   */
  function luxe_instagram_ul_filter($classes) {
    return 'instragram-feed-wrap';
  }
  add_filter( 'wpiw_list_class', 'luxe_instagram_ul_filter' );
}