<?php
/**
 * Template Name: Blog List
 *
 * @package photosy
*/
get_header();
if (get_query_var('paged')) {
  $paged = get_query_var('paged');
} elseif (get_query_var('page')) {
  $paged = get_query_var('page');
} else {
  $paged = 1;
}

$author_avatar = photosy_get_post_opt('blog-post-author-avatar');
$author_name   = photosy_get_post_opt('blog-post-author-name');
$post_date     = photosy_get_post_opt('blog-post-post-date');
$post_tags     = photosy_get_post_opt('blog-post-tags');
$post_cats     = photosy_get_post_opt('blog-post-category');
$post_per_page = photosy_get_post_opt('blog-post-per-page');

$categories = photosy_get_post_opt('blog-category');

if (!$post_per_page) {
  $post_per_page = get_option('posts_per_page');
}

$post_args = array(
  'posts_per_page' => $post_per_page,
  'orderby'        => photosy_get_post_opt('blog-post-orderby'),
  'paged'          => $paged,
  'order'          => photosy_get_post_opt('blog-post-order'),
  'post_type'      => 'post',
  'post_status'    => 'publish'
);

if (is_array($categories)) {
  $post_args['category__in'] =  $categories;
}

$query = new WP_Query( $post_args );
if(is_page()) {
  $max_num_pages = $query->max_num_pages;
} else {
  global $wp_query;
  $query = $wp_query;
  $max_num_pages = false;
}

?>
<div class="content">
  <div class="marg-lg-b100 marg-md-b60 marg-xs-b30"></div>
  <section class="section">
    <div class="container">
      <?php get_template_part('theme/inc/global/blog-before-content'); ?>
      <?php if($query -> have_posts()): while ($query -> have_posts()) : $query -> the_post(); ?>
      <div <?php post_class('blog_item'); ?>>
        <?php photosy_blog_post_format(); ?>
        <div class="twit-desc">
          <?php if($post_cats || !class_exists('ReduxFramework') || is_home()): ?>
            <span class="category"><?php echo get_the_category_list( esc_html__( ', ', 'photosy' ) );?></span>
          <?php endif; ?>
          <h2 class="h2 title"><a href="<?php echo esc_url(get_the_permalink()); ?>"><?php the_title(); ?></a></h2>
            <?php if(is_sticky()): ?><i class="material-icons post-sticky-icon">bookmark_border</i><?php endif; ?>
            <div class="twit-author">
              <div class="post-txt post-meta">
                <?php if($post_date || !class_exists('ReduxFramework') || is_home()): ?>
                  <span class="post-label"><?php echo esc_html__('Posted on', 'photosy'); ?></span> <span class="post-date"><?php echo get_the_date(get_option('date_format')); ?></span>
                <?php endif; ?>
                <?php if($author_name || !class_exists('ReduxFramework') || is_home()): ?>
                  <span class="admin"><a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' )); ?>"><span class="post-label"><?php echo esc_html__('by', 'photosy'); ?></span> <?php echo get_the_author(); ?></a></span>
                <?php endif; ?>
            </div>
          </div>

          <div class="simple-text">
            <p><?php echo photosy_auto_post_excerpt(); ?></p>
          </div>
          <a href="<?php echo esc_url(get_the_permalink()); ?>" class="link-type-1"><?php echo esc_html__('Read More', 'photosy'); ?><i class="material-icons"><?php echo esc_html__('navigate_next', 'photosy'); ?></i></a>

        </div>
      </div>
      <?php endwhile; wp_reset_postdata(); else:
        get_template_part('theme/inc/content/content-none');
      endif; ?>
      <?php photosy_paging_nav($max_num_pages, 'default'); ?>
      <?php get_template_part('theme/inc/global/blog-after-content'); ?>
    </div>
  </section>
  <div class="marg-lg-b100 marg-md-b60 marg-xs-b30"></div>
</div>

<?php
get_footer();
