<?php
/**
 * Template Name: Portfolio Split Slider Style 2
 *
 * @package photosy
*/
get_header();

wp_enqueue_script('multiscroll-responsive');
wp_enqueue_script('multiscroll');
wp_enqueue_script('easing');
wp_enqueue_style('multiscroll');

$cats           = photosy_get_post_opt('portfolio-category');
$posts_per_page = photosy_get_post_opt('portfolio-post-per-page');
$posts_order    = photosy_get_post_opt('portfolio-post-order');
$posts_orderby  = photosy_get_post_opt('portfolio-post-orderby');
$args = array(
  'posts_per_page' => $posts_per_page,
  'meta_query'     => array(array('key' => '_thumbnail_id')),
  'orderby'        => $posts_orderby,
  'order'          => $posts_order,
  'post_type'      => 'portfolio',
);

$args['tax_query'] = array(
  array(
    'taxonomy' => 'portfolio-category',
    'field'    => 'slug',
    'terms'    => $cats,
  ),
);

$the_query = new WP_Query($args);

$the_posts = array();
if( $the_query->have_posts() ):
  while( $the_query->have_posts() ) : $the_query->the_post();
  $image = wp_get_attachment_image_src( get_post_thumbnail_id(), 'full' );
  $image_right = class_exists('RSMultiPostThumbnails') ?  RSMultiPostThumbnails::get_post_thumbnail_url('portfolio', 'featured-secondary-image', NULL):'';
  $image       = ( ! empty( $image ) ) ? $image[0] : '';
  $image_right = (empty($image_right) || !isset($image_right)) ? $image:$image_right;

  $the_posts[] = array(
    'id'                  => get_the_id(),
    'title'               => get_the_title(),
    'image'               => $image,
    'image_right'         => $image_right,
    'term'                => wp_get_post_terms(get_the_ID(), 'portfolio-category'),
    'permalink'           => get_the_permalink(),
  );

  endwhile;
  wp_reset_postdata();
endif;

$total_posts = count( $the_posts );

// convert odd to nearest lowest even
$total_posts = ($total_posts % 2 == 0) ? $total_posts:$total_posts - 1;
if( ! empty( $the_posts ) && $total_posts > 1 ):

  ?>

  <div class="scroll-slider-content tb-multi__scroll with-padding slider-2" data-anchor-count="<?php echo esc_attr($total_posts); ?>">
  <div class="ss-top-padding"></div>
  <div class="ss-bottom-padding"></div>
    <div class="scroll-slider-wrap">
      <div class="scroll-control-btn">
        <ul id="scroll-count">
          <?php for($i = 1; $i <= $total_posts; $i++):
            $active_class = ($i == 1) ? ' class="active"':'';
          ?>
            <li data-menuanchor="anchor<?php echo esc_attr($i); ?>"<?php echo wp_kses_data($active_class); ?>><a href="#anchor<?php echo esc_attr($i); ?>"><?php echo esc_attr($i); ?></a></li>
          <?php endfor;?>
        </ul>
        <span class="total-slide"></span>
      </div>
      <div id="scroll-slider">

        <?php $column_left_posts = array_slice( $the_posts, 0, $total_posts ); ?>
        <div class="ms-left">
          <?php foreach( $column_left_posts as $left_post_key => $left_post_val ):
            $term_name = array();
            if (count($left_post_val['term']) > 0):
              foreach ($left_post_val['term'] as $term):
                $term_name[] = $term->name;
              endforeach;
            endif;
          ?>
          <div class="ms-section" data-bg-color="#ff0000" id="left<?php echo esc_attr($left_post_key); ?>">
            <a href="<?php echo wp_kses_post($left_post_val['permalink']); ?>" target="_blank">
              <img src="<?php echo esc_url($left_post_val['image']); ?>" alt="">
              <div class="slider-fixed-test">
                <h2><?php echo wp_kses_post($left_post_val['title']); ?></h2>
                <p><?php echo implode('/', $term_name); ?></p>
              </div>
            </a>
          </div>
          <?php endforeach; ?>
        </div>

        <?php $column_right_posts = array_slice( $the_posts, 0, $total_posts); ?>
        <div class="ms-right">
          <?php foreach( $column_right_posts as $right_post_key => $right_post_val ):
            $term_name_right = array();
            if (count($right_post_val['term']) > 0):
              foreach ($right_post_val['term'] as $term):
                $term_name_right[] = $term->name;
              endforeach;
            endif;
          ?>
          <div class="ms-section" data-bg-color="#eeee22" id="right<?php echo esc_attr($right_post_key); ?>">
            <a href="<?php echo wp_kses_post($right_post_val['permalink']); ?>" target="_blank">
              <img src="<?php echo esc_url($right_post_val['image_right']); ?>" alt="">
              <div class="slider-fixed-test">
                <h2><?php echo wp_kses_post($right_post_val['title']); ?></h2>
                <p><?php echo implode('/', $term_name_right); ?></p>
              </div>
            </a>
          </div>
          <?php endforeach; ?>
        </div>

      </div>
    </div>
  </div>
<?php endif;

get_footer();
