<?php

/**
 *
 * Hex to Rgba
 * @since 1.0.0
 * @version 1.0.0
 *
 */
if( ! function_exists( 'photosy_hex2rgba' ) ) {
  function photosy_hex2rgba( $hexcolor, $opacity = 1 ) {

    $hex    = str_replace( '#', '', $hexcolor );

    if( strlen( $hex ) == 3 ) {
      $r    = hexdec( substr( $hex, 0, 1 ) . substr( $hex, 0, 1 ) );
      $g    = hexdec( substr( $hex, 1, 1 ) . substr( $hex, 1, 1 ) );
      $b    = hexdec( substr( $hex, 2, 1 ) . substr( $hex, 2, 1 ) );
    } else {
      $r    = hexdec( substr( $hex, 0, 2 ) );
      $g    = hexdec( substr( $hex, 2, 2 ) );
      $b    = hexdec( substr( $hex, 4, 2 ) );
    }

    return ( isset( $opacity ) && $opacity != 1 ) ? 'rgba('. $r .', '. $g .', '. $b .', '. $opacity .')' : ' ' . $hexcolor;
  }
}

/**
 *
 * Get Fontawesome Icons
 * @since 1.0.0
 * @version 1.0.0
 *
 */
if( !function_exists('photosy_fontawesome_icons')) {
  function photosy_fontawesome_icons() {

    $icons_keys = array();
    foreach($icons as $icon) {
      $icons_keys[] = str_replace('fa fa-', '', $icon);
    }
    return array_combine($icons_keys, $icons);
  }
}

/**
 *
 * Get Font Icons
 * @since 1.0.0
 * @version 1.0.0
 *
 */
if( !function_exists('photosy_font_icons')) {
  function photosy_font_icons() {
    
  }
}

/**
 *
 * Set WPAUTOP for shortcode output
 * @since 1.0.0
 * @version 1.0.0
 *
 */
if( ! function_exists( 'photosy_set_wpautop' ) ) {
  function photosy_set_wpautop( $content, $force = true ) {
    if ( $force ) {
      $content = wpautop( preg_replace( '/<\/?p\>/', "\n", $content ) . "\n" );
    }
    return do_shortcode( shortcode_unautop( $content ) );
  }
}

/**
 *
 * element values post, page, categories
 * @since 1.0.0
 * @version 1.0.0
 *
 */
if ( ! function_exists( 'photosy_element_values' ) ) {
  function photosy_element_values(  $type = '', $query_args = array() ) {

    $options = array();

    switch( $type ) {

      case 'pages':
      case 'page':
      $pages = get_pages( $query_args );

      if ( !empty($pages) ) {
        foreach ( $pages as $page ) {
          $options[$page->post_title] = $page->ID;
        }
      }
      break;

      case 'posts':
      case 'post':
      $posts = get_posts( $query_args );

      if ( !empty($posts) ) {
        foreach ( $posts as $post ) {
          $options[$post->post_title] = lcfirst($post->ID);
        }
      }
      break;

      case 'tags':
      case 'tag':

	  if (isset($query_args['taxonomies']) && taxonomy_exists($query_args['taxonomies'])) {
		$tags = get_terms( $query_args['taxonomies'], $query_args['args'] );
		  if ( !is_wp_error($tags) && !empty($tags) ) {
			foreach ( $tags as $tag ) {
			  $options[$tag->name] = $tag->term_id;
		  }
		}
	  }
      break;

      case 'categories':
      case 'category':

	  if (isset($query_args['taxonomy']) && taxonomy_exists($query_args['taxonomy'])) {
  		$categories = get_categories( $query_args );
  		if ( !empty($categories) && is_array($categories) ) {
  		  foreach ( $categories as $category ) {
  			 $options[$category->name] = $category->slug;
  		  }
  		}
	  }
      break;

      case 'custom':
      case 'callback':

      if( is_callable( $query_args['function'] ) ) {
        $options = call_user_func( $query_args['function'], $query_args['args'] );
      }

      break;

    }

    return $options;

  }
}
/**
 *
 * Get Bootstrap Col
 * @since 1.0.0
 * @version 1.0.0
 *
 */
if( ! function_exists( 'photosy_get_bootstrap_col' ) ) {
  function photosy_get_bootstrap_col( $width = '' ) {
    $width = explode('/', $width);
    $width = ( $width[0] != '1' ) ? $width[0] * floor(12 / $width[1]) : floor(12 / $width[1]);
    return  $width;
  }
}

/**
 * Get font choices for theme options
 * @param bool $return_string if true returned array is strict, example array item: font_name => font_label
 * @return array
 */
if(!function_exists('photosy_get_font_choices')) {
  function photosy_get_font_choices($return_strict = false) {
    $aFonts = array(
      array(
        'value' => 'default',
        'label' => esc_html__('Default', 'animo-addons'),
        'src' => ''
      ),
      array(
        'value' => 'Verdana',
        'label' => 'Verdana',
        'src' => ''
      ),
      array(
        'value' => 'Geneva',
        'label' => 'Geneva',
        'src' => ''
      ),
      array(
        'value' => 'Proxima Nova',
        'label' => 'Proxima Nova',
        'src' => ''
      ),
      array(
        'value' => 'Arial',
        'label' => 'Arial',
        'src' => ''
      ),
      array(
        'value' => 'Arial Black',
        'label' => 'Arial Black',
        'src' => ''
      ),
      array(
        'value' => 'Trebuchet MS',
        'label' => 'Trebuchet MS',
        'src' => ''
      ),
      array(
        'value' => 'Helvetica',
        'label' => 'Helvetica',
        'src' => ''
      ),
      array(
        'value' => 'sans-serif',
        'label' => 'sans-serif',
        'src' => ''
      ),
      array(
        'value' => 'Georgia',
        'label' => 'Georgia',
        'src' => ''
      ),
      array(
        'value' => 'Times New Roman',
        'label' => 'Times New Roman',
        'src' => ''
      ),
      array(
        'value' => 'Times',
        'label' => 'Times',
        'src' => ''
      ),
      array(
        'value' => 'serif',
        'label' => 'serif',
        'src' => ''
      ),
    );

    if (file_exists(PHOTOSY_ROOT . '/composer/google-fonts.json')) {

      $google_fonts = file_get_contents(PHOTOSY_ROOT . '/composer/google-fonts.json', true);
      $aGoogleFonts = json_decode($google_fonts, true);

      if (!isset($aGoogleFonts['items']) || !is_array($aGoogleFonts['items'])) {
        return;
      }

      $aFonts[] = array(
        'value' => 'google_web_fonts',
        'label' => '---Google Web Fonts---',
        'src' => ''
      );

      foreach ($aGoogleFonts['items'] as $aGoogleFont) {
        $aFonts[] = array(
          'value' => 'google_web_font_' . $aGoogleFont['family'],
          'label' => $aGoogleFont['family'],
          'src' => ''
        );
      }
    }

    if ($return_strict) {
      $aFonts2 = array();
      foreach ($aFonts as $font) {
        $aFonts2[$font['value']] = $font['label'];
      }
      return $aFonts2;
    }
    return $aFonts;
  }
}

/**
 *
 * Walker Category
 * @since 1.0.0
 * @version 1.1.0
 *
 */
class Walker_Portfolio_List_Categories extends Walker_Category {

  function start_el( &$output, $category, $depth = 0, $args = array(), $current_object_id = 0 ) {

    $has_children = get_term_children( $category->term_id, 'portfolio-category' );

    if( empty( $has_children ) ) {
      $cat_name = esc_attr( $category->name );
      $cat_name = apply_filters( 'list_cats', $cat_name, $category );
      $link     = '<li data-filter=".'. strtolower( $category->slug ) .'">';
      $link    .= $cat_name;
      $link    .= '</li>';
      $output  .= $link;
    }

  }

  function end_el( &$output, $page, $depth = 0, $args = array() ) {}

}

if(!function_exists('photosy_get_space_array_addons')) {
  /**
   * Get space array
   * @param type $type
   * @return array
  */
  function photosy_get_space_array_addons() {
    $space_array = array('Select Height' => '', 'No Margin' => 'no-margin');
    for($i = 5; $i < 215;) {
      $space_array[] = $i;
      $i = $i + 5;
    }
    return $space_array;
  }
}

if(!function_exists('photosy_get_image_src')) {
  /**
   * Return URL
   * @param type $type
   * @return array
  */
  function photosy_get_image_src( $id ) {
    if(empty($id)) { return ; }
    $image_src = (is_numeric($id)) ? wp_get_attachment_url($id):$id;
    return $image_src;
  }
}


if(!function_exists('photosy_slider_style_one')) {
  /**
   * Slider Style One
   * @param type $type
   * @return type
  */
  function photosy_slider_style_one($the_query, $speed, $autoplay, $slide_change_on_scroll) { ?>

    <div class="content slider-1 type-1">
      <div class="top-baner bottom-margin arrow-closest poind-closest">
        <div class="swiper-container" data-mouse-scroll="<?php echo esc_attr($slide_change_on_scroll); ?>" data-slides-per-view="1" data-autoplay="<?php echo esc_attr($autoplay); ?>" data-speed="<?php echo esc_attr($speed); ?>">
          <div class="swiper-wrapper lightgallery">

            <?php 
              global $post;
              $i = 0; 
              while( $the_query->have_posts() ) : $the_query->the_post(); 
                $terms = wp_get_post_terms(get_the_ID(), 'portfolio-category');
                $term_name = array();
                if (count($terms) > 0):
                  foreach ($terms as $term):
                    $term_name[] = $term->name;
                  endforeach;
                endif;
                $img_url           = get_the_post_thumbnail_url(get_the_ID(), 'full');
                $portfolio_link_to = photosy_get_post_opt('portfolio-link-to');
                $permalink         = ($portfolio_link_to == 'lightbox') ? $img_url:get_the_permalink();
            ?>
              <div class="swiper-slide<?php echo ($i == 0) ? ' first-slide':''; ?>" data-val="<?php echo esc_attr($i); ?>">
                <div class="tt-slider-content-wrapp">
                  <div class="tt-slider-content">
                    <h1 class="tt-slider-title"><?php the_title(); ?></h1>
                    <span class="tt-subtitle"><?php echo implode('/', $term_name); ?></span>
                  </div>
                </div>
                <div class="img-block-wrapp">
                  <div class="bg-slide" style="background-image:url(<?php echo esc_url($img_url); ?>)"></div>
                </div>
                <a href="<?php echo esc_url($permalink); ?>" class="tt-hold-link <?php echo ($portfolio_link_to == 'lightbox') ? 'lightbox-item':''; ?>"></a>
              </div>
            <?php $i++; endwhile; wp_reset_postdata(); ?>
          </div>  
        </div>
        <div class="pagination hidden"></div>
        <div class="swiper-arrow-type-2">
          <div class="swiper-arrow-left swiper-arrow"><i class="material-icons">keyboard_arrow_left</i></div>
          <div class="swiper-arrow-right swiper-arrow"><i class="material-icons">keyboard_arrow_right</i></div>
        </div>
        <div class="slider-number"><span></span><p><b></b></p></div>  
      </div>
    </div>
  <?php
  }
}

if(!function_exists('photosy_slider_style_two')) {
  /**
   * Slider Style One
   * @param type $type
   * @return type
  */
  function photosy_slider_style_two($the_query, $speed, $autoplay, $slide_change_on_scroll) { ?>

    <div class="content slider-1 type-2">
      <div class="top-baner bottom-margin arrow-closest poind-closest">
        <div class="swiper-container" data-mouse-scroll="<?php echo esc_attr($slide_change_on_scroll); ?>" data-slides-per-view="1" data-autoplay="<?php echo esc_attr($autoplay); ?>" data-speed="<?php echo esc_attr($speed); ?>">
          <div class="swiper-wrapper lightgallery">

            <?php 
              $i = 0; 
              while( $the_query->have_posts() ) : $the_query->the_post(); 
                $terms = wp_get_post_terms(get_the_ID(), 'portfolio-category');
                $term_name = array();
                if (count($terms) > 0):
                  foreach ($terms as $term):
                    $term_name[] = $term->name;
                  endforeach;
                endif;
                $img_url = get_the_post_thumbnail_url(get_the_ID(), 'full'); 
                $portfolio_link_to = photosy_get_post_opt('portfolio-link-to');
                $permalink         = ($portfolio_link_to == 'lightbox') ? $img_url:get_the_permalink();      
            ?>
            <div class="swiper-slide <?php echo ($i == 0) ? ' first-slide':''; ?>" data-val="<?php echo esc_attr($i); ?>">
              <div class="col-md-6 tt-slider-content-wrapp">
                <div class="tt-slider-content">
                  <h1 class="tt-slider-title"><?php the_title(); ?></h1>
                    <span class="tt-subtitle"><?php echo implode('/', $term_name); ?></span>
                </div>
              </div>
              <div class="col-md-6 img-block-wrapp" >
                <div class="bg-slide" style="background-image:url(<?php echo esc_url($img_url); ?>)"></div>
              </div>
              <a href="<?php echo esc_url($permalink); ?>" class="tt-hold-link <?php echo ($portfolio_link_to == 'lightbox') ? 'lightbox-item':''; ?>"></a>
            </div>
            <?php $i++; endwhile; wp_reset_postdata(); ?>
          </div>
        </div>
        <div class="pagination hidden"></div>
        <div class="swiper-arrow-type-2">
          <div class="swiper-arrow-left swiper-arrow"><i class="material-icons">keyboard_arrow_left</i></div>
          <div class="swiper-arrow-right swiper-arrow"><i class="material-icons">keyboard_arrow_right</i></div>
        </div>
        <div class="slider-number"><span></span><p><b></b></p></div>  
      </div>
    </div>
  <?php
  }
}

if(!function_exists('photosy_slider_style_three')) {
  /**
   * Slider Style Three
   * @param type $type
   * @return type
  */
  function photosy_slider_style_three($the_query, $speed, $autoplay, $slide_change_on_scroll) { ?>

    <div class="content slider-1 type-3">
      <div class="top-baner bottom-margin arrow-closest poind-closest">
        <div class="swiper-container" data-mouse-scroll="<?php echo esc_attr($slide_change_on_scroll); ?>" data-slides-per-view="1" data-autoplay="<?php echo esc_attr($autoplay); ?>" data-speed="<?php echo esc_attr($speed); ?>">
          <div class="swiper-wrapper lightgallery">

            <?php 
              $i = 0; 
              while( $the_query->have_posts() ) : $the_query->the_post(); 
                $terms = wp_get_post_terms(get_the_ID(), 'portfolio-category');
                $term_name = array();
                if (count($terms) > 0):
                  foreach ($terms as $term):
                    $term_name[] = $term->name;
                  endforeach;
                endif;
                $img_url           = get_the_post_thumbnail_url(get_the_ID(), 'full');
                $portfolio_link_to = photosy_get_post_opt('portfolio-link-to');
                $permalink         = ($portfolio_link_to == 'lightbox') ? $img_url:get_the_permalink();       
            ?>
            <div class="swiper-slide<?php echo ($i == 0) ? ' first-slide':''; ?>" data-val="<?php echo esc_attr($i); ?>">
              <div class="col-md-6 tt-slider-content-wrapp">
                <div class="tt-slider-content">
                  <h1 class="tt-slider-title"><?php the_title(); ?></h1>
                  <span class="tt-subtitle"><?php echo implode('/', $term_name); ?></span>
                </div>
              </div>
              <div class="col-md-6 img-block-wrapp" >
                <div class="bg-slide" style="background-image:url(<?php echo esc_url($img_url); ?>)"></div>
              </div>
              <a href="<?php echo esc_url($permalink); ?>" class="tt-hold-link <?php echo ($portfolio_link_to == 'lightbox') ? 'lightbox-item':''; ?>"></a>
            </div>
            <?php $i++; endwhile; wp_reset_postdata(); ?>
          </div>
        </div>
        <div class="pagination hidden"></div>
        <div class="swiper-arrow-type-2">
          <div class="swiper-arrow-left swiper-arrow"><i class="material-icons">keyboard_arrow_left</i></div>
          <div class="swiper-arrow-right swiper-arrow"><i class="material-icons">keyboard_arrow_right</i></div>
        </div>
        <div class="slider-number"><span></span><p><b></b></p></div>  
      </div>
    </div>
  <?php
  }
}

if(!function_exists('photosy_slider_style_four')) {
  /**
   * Slider Style Three
   * @param type $type
   * @return type
  */
  function photosy_slider_style_four($the_query, $speed, $autoplay, $slide_change_on_scroll) { ?>

    <div class="content slider-1 type-4">
      <div class="top-baner arrow-closest poind-closest custom-pagination-wrapper">
        <div class="swiper-container custom-pagination-slider" data-mouse-scroll="<?php echo esc_attr($slide_change_on_scroll); ?>" data-slides-per-view="1" data-autoplay="<?php echo esc_attr($autoplay); ?>" data-speed="<?php echo esc_attr($speed); ?>">
          <div class="swiper-wrapper">
            <?php 
              $i = 0; 
              while( $the_query->have_posts() ) : $the_query->the_post(); 
                $img_url = get_the_post_thumbnail_url(get_the_ID(), 'full');       
            ?>
            <div class="swiper-slide<?php echo ($i == 0) ? ' first-slide':''; ?>" data-val="<?php echo esc_attr($i); ?>">
              <div class="img-block-wrapp" >
                <div class="bg-slide" style="background-image:url(<?php echo esc_url($img_url); ?>)"></div>
              </div>
            </div>
            <?php $i++; endwhile; wp_reset_postdata(); ?>
          </div>
        </div>
        <div class="tt-slider-content-wrapp custom-pagination">
          <div class="tt-slider-content">
            <ul>
              <?php $i = 0; while( $the_query->have_posts() ) : $the_query->the_post(); ?>
                <li <?php echo ($i == 0) ? ' class="active"':''; ?>><?php the_title(); ?></li>
              <?php $i++; endwhile; wp_reset_postdata(); ?>
            </ul>
          </div>
        </div>
        <div class="pagination hidden"></div>
        <div class="swiper-arrow-type-2">
          <div class="swiper-arrow-left swiper-arrow"><i class="material-icons">keyboard_arrow_left</i></div>
          <div class="swiper-arrow-right swiper-arrow"><i class="material-icons">keyboard_arrow_right</i></div>
        </div>
        <div class="slider-number"><span></span><p><b></b></p></div>  
      </div>
    </div>
  <?php
  }
}

if(!function_exists('photosy_slider_style_five')) {
  /**
   * Slider Style Five
   * @param type $type
   * @return type
  */
  function photosy_slider_style_five($the_query, $speed, $autoplay, $slide_change_on_scroll) { ?>

    <div class="content slider-1 type-5">
      <div class="top-baner bottom-margin arrow-closest poind-closest">
        <div class="swiper-container" data-mouse-scroll="<?php echo esc_attr($slide_change_on_scroll); ?>" data-slides-per-view="1" data-autoplay="<?php echo esc_attr($autoplay); ?>" data-speed="<?php echo esc_attr($speed); ?>">
          <div class="swiper-wrapper lightgallery">

            <?php 
              $i = 0; 
              while( $the_query->have_posts() ) : $the_query->the_post(); 
                $terms = wp_get_post_terms(get_the_ID(), 'portfolio-category');
                $term_name = array();
                if (count($terms) > 0):
                  foreach ($terms as $term):
                    $term_name[] = $term->name;
                  endforeach;
                endif;
                $img_url           = get_the_post_thumbnail_url(get_the_ID(), 'full');
                $portfolio_link_to = photosy_get_post_opt('portfolio-link-to');
                $permalink         = ($portfolio_link_to == 'lightbox') ? $img_url:get_the_permalink();              
            ?>

            <div class="swiper-slide<?php echo ($i == 0) ? ' first-slide':''; ?>" data-val="<?php echo esc_attr($i); ?>">
              <div class="col-md-6 tt-slider-content-wrapp">
                <div class="tt-slider-content">
                  <h1 class="tt-slider-title"><?php the_title(); ?></h1>
                  <span class="tt-subtitle"><?php echo implode('/', $term_name); ?></span>
                </div>
              </div>
              <div class="col-md-6 img-block-wrapp" >
                <div class="bg-slide" style="background-image:url(<?php echo esc_url($img_url); ?>)"></div>
                <div class="tt-border"></div>
              </div>
              <a href="<?php echo esc_url($permalink); ?>" class="tt-hold-link <?php echo ($portfolio_link_to == 'lightbox') ? 'lightbox-item':''; ?>"></a>
            </div>
            <?php $i++; endwhile; wp_reset_postdata(); ?>
          </div>
        </div>
        <div class="pagination hidden"></div>
        <div class="swiper-arrow-type-2">
          <div class="swiper-arrow-left swiper-arrow"><i class="material-icons">keyboard_arrow_left</i></div>
          <div class="swiper-arrow-right swiper-arrow"><i class="material-icons">keyboard_arrow_right</i></div>
        </div>
        <div class="slider-number"><span></span><p><b></b></p></div>  
      </div>
    </div>
  <?php
  }
}



if(!function_exists('photosy_slider_style_six')) {
  /**
   * Slider Style Seven
   * @param type $type
   * @return type
  */
  function photosy_slider_style_six($the_query, $speed, $autoplay, $slide_change_on_scroll) { ?>

    <div class="content no-padd slider-1 type-7">
      <div class="top-baner arrow-closest poind-closest">
        <div class="swiper-container thumbnails-preview" data-mouse-scroll="<?php echo esc_attr($slide_change_on_scroll); ?>" data-slides-per-view="1" data-autoplay="<?php echo esc_attr($autoplay); ?>" data-speed="<?php echo esc_attr($speed); ?>">
          <div class="swiper-wrapper lightgallery">

            <?php 
              $i = 0; 
              while( $the_query->have_posts() ) : $the_query->the_post(); 
                $img_url           = get_the_post_thumbnail_url(get_the_ID(), 'full');
                $portfolio_link_to = photosy_get_post_opt('portfolio-link-to');
                $permalink         = ($portfolio_link_to == 'lightbox') ? $img_url:get_the_permalink();              
            ?>
            <div class="swiper-slide<?php echo ($i == 0) ? ' first-slide':''; ?>" data-val="<?php echo esc_attr($i); ?>">
              <div class="img-block-wrapp" >
                <div class="bg-slide" style="background-image:url(<?php echo esc_url($img_url); ?>)"></div>
              </div>
              <a href="<?php echo esc_url($permalink); ?>" class="tt-hold-link <?php echo ($portfolio_link_to == 'lightbox') ? 'lightbox-item':''; ?>"></a>
            </div>
            <?php $i++; endwhile; wp_reset_postdata(); ?>
          </div>
        </div>

        <div class="pagination hidden"></div>
        <div class="swiper-arrow-type-2 hidden">
          <div class="swiper-arrow-left swiper-arrow"><i class="material-icons">keyboard_arrow_left</i></div>
          <div class="swiper-arrow-right swiper-arrow"><i class="material-icons">keyboard_arrow_right</i></div>
        </div>
        <div class="slider-number hidden"><span></span><p><b></b></p></div>

        <div class="swiper-container thumbnails" data-slides-per-view="responsive" data-add-slides="5" data-lg-slides="5" data-md-slides="3" data-sm-slides="3" data-xs-slides="1" data-speed="800">
            <div class="swiper-wrapper">

              <?php 
                $i = 0; 
                while( $the_query->have_posts() ) : $the_query->the_post(); 
                  $terms = wp_get_post_terms(get_the_ID(), 'portfolio-category');
                  $term_name = array();
                  if (count($terms) > 0):
                    foreach ($terms as $term):
                      $term_name[] = $term->name;
                    endforeach;
                  endif;
                  $img_url = get_the_post_thumbnail_url(get_the_ID(), 'thumbnail');       
              ?>
              <div class="swiper-slide<?php echo ($i == 0) ? ' current first-slide':''; ?>" data-val="<?php echo esc_attr($i); ?>">
                <div class="thumb-item">
                  <div class="thumb-image">
                    <img src="<?php echo esc_url($img_url); ?>" height="100" width="100" alt="">
                  </div>
                  <div class="thumb-info">
                    <div class="thumb-title"><?php the_title(); ?></div>
                    <div class="thumb-subtitle"><?php echo implode('/', $term_name); ?></div>
                  </div>
                </div>
              </div>
              <?php $i++; endwhile; wp_reset_postdata(); ?>
            </div>
        </div>
      </div>
    </div>
  <?php
  }
}

if(!function_exists('photosy_slider_style_seven')) {
  /**
   * Slider Style Seven
   * @param type $type
   * @return type
  */
  function photosy_slider_style_seven($the_query, $speed, $autoplay, $slide_change_on_scroll) { ?>

    <div class="content slider-1 type-8">
      <div class="top-baner bottom-margin arrow-closest poind-closest">
        <div class="container swiper-container" data-mouse-scroll="<?php echo esc_attr($slide_change_on_scroll); ?>" data-slides-per-view="1" data-loop="0" data-effect="slide" data-autoplay="<?php echo esc_attr($autoplay); ?>" data-speed="<?php echo esc_attr($speed); ?>">
          <div class="swiper-wrapper lightgallery">

            <?php 
              $i = 0; 
              while( $the_query->have_posts() ) : $the_query->the_post(); 
                $terms = wp_get_post_terms(get_the_ID(), 'portfolio-category');
                $term_name = array();
                if (count($terms) > 0):
                  foreach ($terms as $term):
                    $term_name[] = $term->name;
                  endforeach;
                endif;
                $img_url           = get_the_post_thumbnail_url(get_the_ID(), 'full');
                $portfolio_link_to = photosy_get_post_opt('portfolio-link-to');
                $permalink         = ($portfolio_link_to == 'lightbox') ? $img_url:get_the_permalink();                     
            ?>

            <div class="swiper-slide<?php echo ($i == 0) ? ' first-slide':''; ?>" data-val="<?php echo esc_attr($i); ?>">
              <div class="tt-slider-content-wrapp">
                <div class="tt-slider-content">
                  <h1 class="tt-slider-title"><?php the_title(); ?></h1>
                  <span class="tt-subtitle"><?php echo implode('/', $term_name); ?></span>
                </div>
              </div>
              <div class="img-block-wrapp" >
                <div class="bg-slide" style="background-image:url(<?php echo esc_url($img_url); ?>)"></div>
              </div>
              <a href="<?php echo esc_url($permalink); ?>" class="tt-hold-link <?php echo ($portfolio_link_to == 'lightbox') ? 'lightbox-item':''; ?>"></a>
            </div>
            <?php $i++; endwhile; wp_reset_postdata(); ?>

          </div>
        </div>
        <div class="pagination hidden"></div>
        <div class="swiper-arrow-type-2">
          <div class="swiper-arrow-left swiper-arrow"><i class="material-icons">keyboard_arrow_left</i></div>
          <div class="swiper-arrow-right swiper-arrow"><i class="material-icons">keyboard_arrow_right</i></div>
        </div>
        <div class="slider-number"><span></span><p><b></b></p></div>  
      </div>
    </div>
  <?php
  }
}

if(!function_exists('photosy_slider_style_eight')) {
  /**
   * Slider Style Eight
   * @param type $type
   * @return type
  */
  function photosy_slider_style_eight($the_query, $speed, $autoplay, $slide_change_on_scroll) { ?>

    <div class="content no-padd slider-1 type-9">
      <div class="top-baner arrow-closest poind-closest">
        <div class="swiper-container" data-mouse-scroll="<?php echo esc_attr($slide_change_on_scroll); ?>" data-slides-per-view="1" data-autoplay="<?php echo esc_attr($autoplay); ?>" data-speed="<?php echo esc_attr($speed); ?>">
          <div class="swiper-wrapper lightgallery">
            <?php 
              $i = 0; 
              while( $the_query->have_posts() ) : $the_query->the_post(); 
                $img_url           = get_the_post_thumbnail_url(get_the_ID(), 'full');
                $portfolio_link_to = photosy_get_post_opt('portfolio-link-to');
                $permalink         = ($portfolio_link_to == 'lightbox') ? $img_url:get_the_permalink();                     
            ?>
            <div class="swiper-slide<?php echo ($i == 0) ? ' first-slide':''; ?>" data-val="<?php echo esc_attr($i); ?>">
              <div class="img-block-wrapp" >
                <div class="bg-slide" style="background-image:url(<?php echo esc_url($img_url); ?>)"></div>
              </div>
              <a href="<?php echo esc_url($permalink); ?>" class="tt-hold-link <?php echo ($portfolio_link_to == 'lightbox') ? 'lightbox-item':''; ?>"></a>
            </div>
            <?php $i++; endwhile; wp_reset_postdata(); ?>
          </div>
        </div>
        <div class="pagination hidden"></div>
        <div class="swiper-arrow-type-2">
          <div class="swiper-arrow-left swiper-arrow"><i class="material-icons">keyboard_arrow_left</i></div>
          <div class="swiper-arrow-right swiper-arrow"><i class="material-icons">keyboard_arrow_right</i></div>
        </div>
        <div class="slider-number"><span></span><p><b></b></p></div>  
      </div>
    </div>
  <?php
  }
}

if(!function_exists('photosy_slider_style_nine')) {
  /**
   * Slider Style Nine
   * @param type $type
   * @return type
  */
  function photosy_slider_style_nine($the_query, $speed, $autoplay, $slide_change_on_scroll) { ?>

    <div class="swiper-wrap swiper-slider-1 swiper-style-3">
      <div class="swiper-container" data-mouse-scroll="<?php echo esc_attr($slide_change_on_scroll); ?>" data-autoplay="<?php echo esc_attr($autoplay); ?>" data-speed="<?php echo esc_attr($speed); ?>">
        <div class="swiper-wrapper">
          <?php 
              $i = 0; 
              while( $the_query->have_posts() ) : $the_query->the_post(); 
                $img_url           = get_the_post_thumbnail_url(get_the_ID(), 'full');
                $portfolio_link_to = photosy_get_post_opt('portfolio-link-to');
                $permalink         = ($portfolio_link_to == 'lightbox') ? $img_url:get_the_permalink();                     
            ?>
          <div class="swiper-slide">
            <div class="bg-slide" style="background-image:url(<?php echo esc_url($img_url); ?>)"></div>
            <div class="tt-slider-content">
              <h1 class="tt-slider-title"><?php the_title(); ?></h1>
              <span class="tt-subtitle">People, Place</span>
            </div>
            <a href="<?php echo esc_url($permalink); ?>" class="tt-hold-link <?php echo ($portfolio_link_to == 'lightbox') ? 'lightbox-item':''; ?>"></a>
          </div>
          <?php $i++; endwhile; wp_reset_postdata(); ?>
          
        </div><!-- .swiper-wrapper -->
      </div>
      <div class="swiper-controlar white-color">
        <div class="swiper-arrow">
          <div class="swiper-arrow-left">Privious</div>
          <div class="swiper-arrow-right">Next</div>
        </div>
        <!-- Pagination -->
        <div class="expanded-timeline">
          <div class="swiper-counter"><span></span><span></span></div>
        </div>
      </div>
    </div>
  <?php
  }
}