<?php
/**
 *
 * RS Portfolio
 * @since 1.0.0
 * @version 1.0.0
 *
 */
function photosy_portfolio($atts, $content = '', $id = '') {
  global $post;
  extract(shortcode_atts(array(
    'id'      => '',
    'class'   => '',
    'style'   => 'style1',
    'orderby' => 'ID',
    'order'   => 'DESC',
    'limit'   => 4,
    'cats'    => '',
  ), $atts));

  $class = ( $class ) ? ' ' .$class : '';
  $limit = (empty($limit)) ? 4:$limit;


  $args = array(
    'posts_per_page' => $limit,
    'meta_query'     => array(array('key' => '_thumbnail_id')),
    'orderby'        => $orderby,
    'order'          => $order,
    'post_type'      => 'portfolio',
  );

  $args['tax_query'] = array(
    array(
      'taxonomy' => 'portfolio-category',
      'field'    => 'slug',
      'terms'    => explode(',', $cats),
    ),
  );

  switch ($style) {
    default:
    case 'style1':
      $image_size    = array('photosy-square-small');
      $section_class = 'home-portfolio1';
      break;
    case 'style2':
      $section_class = 'home-portfolio2';
        $image_size = array(
          'wh-60|photosy-square-medium',
          'wh-30|photosy-square-small',
          'wh-30|photosy-square-small'
        );
      break;
    case 'style3':
      $section_class = 'home-portfolio3';
      $image_size = array(
        'wh-30|photosy-square-small',
        'wh-60|photosy-rectangle-medium',
        'wh-30|photosy-square-small',
        'wh-30|photosy-square-small',
        'wh-30|photosy-square-small'
      );
      break;
    case 'style4':
      $section_class = 'home-portfolio4';
      $image_size    = array('photosy-rectangle-large');
      break;
  }


  ob_start();

  $the_query = new WP_Query($args); ?>

  <section class="home-portfolio <?php echo esc_attr($section_class); ?> lightgallery">
    <div class="containers">
      <?php 
        $slug_array = explode(',', $cats);
        $terms = get_terms('portfolio-category', array('orderby' => 'name', 'slug' => $slug_array));
        if(count($terms) > 0): ?>
          <ul class="isotope-filter">
            <li class="active"><a href="#" data-filter="*"><?php echo esc_html__('All', 'photosy-addons'); ?></a></li>
            <?php foreach ($terms as $term): ?>
              <li><a href="#" data-filter=".<?php echo esc_attr($term->slug); ?>"><?php echo esc_html($term->name); ?></a></li>
            <?php endforeach; ?>
          </ul>
      <?php 
        endif; 
      ?>
      <div class="row izotope-container">
        <div class="grid-sizer"></div>
        <?php 
          $i = 0;
          while ($the_query -> have_posts()) : $the_query -> the_post();
            $i = ($i >= count($image_size)) ? 0:$i;
            $terms = wp_get_post_terms(get_the_ID(), 'portfolio-category');
            $term_slugs = array();
            $term_names = array();
            if (count($terms) > 0):
              foreach ($terms as $term):
                $term_slugs[] = $term->slug;
                $term_names[] = $term->name;
              endforeach;
            endif; 
            $args = array(
              'count'      => $i,
              'style'      => $style,
              'link_to'    => photosy_get_post_opt('portfolio-link-to'),
            );
            photosy_portfolio_items($args, $image_size, $term_slugs, $term_names);
            $i++;
          endwhile; wp_reset_postdata(); 
        ?>
      </div>
    </div>
  </section>
  <?php
  $output = ob_get_clean();
  return $output;
}
add_shortcode('photosy_portfolio', 'photosy_portfolio');

if(!function_exists('photosy_portfolio_items')) {
  function photosy_portfolio_items($args, $image_size, $term_slugs, $term_names) {
    global $post;
    extract($args);
    $image_src  = wp_get_attachment_image_src( get_post_thumbnail_id($post->ID), 'photosy-rectangle-medium-alt' );
    $permalink  = ($link_to == 'lightbox') ? $image_src[0]:get_the_permalink();
    switch ($style) {
      case 'style1': ?>
        <div class="item wh-30 <?php echo sanitize_html_classes(implode(' ', $term_slugs)); ?>">
          <div class="item-drid-size">
            <?php the_post_thumbnail($image_size[0], array('class' => 'resp-img')); ?>
            <a href="<?php echo esc_url($permalink); ?>" class="link-wrap item-hov<?php echo ($link_to == 'lightbox') ? ' lightbox-item':''; ?>"></a>
            <div class="item-desc">
              <h4 class="h4"><?php the_title(); ?></h4>
              <span><?php echo sanitize_html_classes(implode(' ', $term_names)); ?></span>
            </div>
          </div>
        </div>
        <?php 
        break;
      case 'style2':
      case 'style3':
        $count              = ( $count < count($image_size) ) ? $count:0;
        $image_attr         = explode('|', $image_size[$count]);
        $featured_image_src = wp_get_attachment_image_src( get_post_thumbnail_id($post->ID), $image_attr[1] ); ?>
        <div class="item <?php echo sanitize_html_classes($image_attr[0]); ?> <?php echo sanitize_html_classes(implode(' ', $term_slugs)); ?>">
          <div class="item-drid-size">
            <img src="<?php echo esc_url($featured_image_src[0]); ?>" class="resp-img wp-post-image" alt="" />
            <a href="<?php echo esc_url($permalink); ?>" class="link-wrap item-hov<?php echo ($link_to == 'lightbox') ? ' lightbox-item':''; ?>"></a>
            <div class="item-desc">
              <h4 class="h4"><?php the_title(); ?></h4>
              <span><?php echo sanitize_html_classes(implode(' ', $term_names)); ?></span>
            </div>
          </div>
        </div>
        <?php
        break;
      case 'style4': ?>
        <div class="item wh-100 <?php echo sanitize_html_classes(implode(' ', $term_slugs)); ?>">
          <div class="item-drid-size">
            <?php the_post_thumbnail($image_size[0], array('class' => 'resp-img')); ?>
            <a href="<?php echo esc_url($permalink); ?>" class="link-wrap item-hov<?php echo ($link_to == 'lightbox') ? ' lightbox-item':''; ?>"></a>
            <div class="item-desc">
              <h4 class="h4"><?php the_title(); ?></h4>
              <span><?php echo sanitize_html_classes(implode(' ', $term_names)); ?></span>
            </div>
          </div>
        </div>
        <?php
      break;
    }
  }
}