<?php
/**
 *
 * RS Portfolio
 * @since 1.0.0
 * @version 1.0.0
 *
 */
function photosy_portfolio_masonry($atts, $content = '', $id = '') {
  global $post;
  extract(shortcode_atts(array(
    'id'                    => '',
    'class'                 => '',
    'column'                => 2,
    'space_between_columns' => 'yes',
    'show_filter'           => 'no',
    'limit'                 => 4,
    'cats'                  => '',
  ), $atts));

  $class = ( $class ) ? ' ' .$class : '';
  $limit = (empty($limit)) ? 4:$limit;

  switch ($column) {
    default:
    case 2:
      $image_size   = array(
        'wh-50|photosy-rectangle-medium',
        'wh-50|photosy-rectangle-medium-alt',
        'wh-50|photosy-square-medium',
        'wh-50|photosy-large-hor',
      );
    break;
    case 3:
      $image_size   = array(
        'wh-30|photosy-square-medium',
        'wh-30|photosy-large-hor',
        'wh-30|photosy-square-medium',
        'wh-30|photosy-rectangle-medium-alt',
      );
    break;
    case 4:
      $image_size   = array(
        'wh-25|photosy-small-ver',
        'wh-25|photosy-small-medium',
        'wh-25|photosy-rectangle-medium-alt',
        'wh-25|photosy-square-small',
      );
    break;
  }

  $args = array(
    'posts_per_page' => $limit,
    'meta_query'     => array(array('key' => '_thumbnail_id')),
    'orderby'        => 'date',
    'post_type'      => 'portfolio',
  );

  $args['tax_query'] = array(
    array(
      'taxonomy' => 'portfolio-category',
      'field'    => 'slug',
      'terms'    => explode(',', $cats),
    ),
  );

  ob_start();

  $the_query = new WP_Query($args);
  $max_num_pages = $the_query->max_num_pages; ?>


  <section class="section home-portfolio portfolio-masonry-wrapper <?php echo esc_attr($class); ?>">

    <?php 
        $slug_array = explode(',', $cats);
        $terms = get_terms('portfolio-category', array('orderby' => 'name', 'slug' => $slug_array));
        if(count($terms) > 0 && $show_filter == 'yes'): ?>
          <ul class="isotope-filter text-center">
            <li class="active"><a href="#" data-filter="*"><?php echo esc_html__('All', 'photosy-addons'); ?></a></li>
            <?php foreach ($terms as $term): ?>
              <li><a href="#" data-filter=".<?php echo esc_attr($term->slug); ?>"><?php echo esc_html($term->name); ?></a></li>
            <?php endforeach; ?>
          </ul>
      <?php 
        endif; 
    ?>

    <div class="portfolio portfolio-masonry <?php echo ($space_between_columns == 'yes') ? 'has-gutter':'no-gutter'; ?> izotope-container lightgallery">
    <div class="grid-sizer"></div>
      <?php
        $count = 0;
        while ($the_query -> have_posts()) : $the_query -> the_post();
          $count = ($count > 3) ? 0:$count;
          $terms = wp_get_post_terms(get_the_ID(), 'portfolio-category');
          $term_slugs = array();
          $term_names = array();
          if (count($terms) > 0):
            foreach ($terms as $term):
              $term_slugs[] = $term->slug;
              $term_names[] = $term->name;
            endforeach;
          endif;
          $args = array(
            'posts_per_page' => $limit,
            'count'          => $count,
            'limit'          => $limit,
            'link_to'        => photosy_get_post_opt('portfolio-link-to'),
          );
          photosy_portfolio_masonry_items($args, $image_size, $term_slugs, $term_names);
          $count++;
        endwhile;
        wp_reset_postdata();
      ?>
    </div>
  </section>
  <?php

  $output = ob_get_clean();
  return $output;
}

add_shortcode('photosy_portfolio_masonry', 'photosy_portfolio_masonry');

if(!function_exists('photosy_portfolio_masonry_items')) {
  function photosy_portfolio_masonry_items($args, $image_size, $term_slugs, $term_names) {
    extract($args);
    global $post;
      $image_src  = wp_get_attachment_image_src( get_post_thumbnail_id($post->ID), 'photosy-rectangle-medium-alt' );
      $permalink  = ($link_to == 'lightbox') ? $image_src[0]:get_the_permalink();
      $count      = ( $count < 4 ) ? $count:0;
      $image_attr = explode('|', $image_size[$count]);
    ?>
    <div class="portfolio-item item <?php echo sanitize_html_classes($image_attr[0]); ?> <?php echo sanitize_html_classes(implode(' ', $term_slugs)); ?>">
      <div class="item-drid-size">
        <?php the_post_thumbnail($image_attr[1], array('class' => 'resp-img')); ?>
        <a href="<?php echo esc_url($permalink); ?>" class="link-wrap item-hov  <?php echo ($link_to == 'lightbox') ? 'lightbox-item':''; ?>"></a>
         <div class="item-desc">
          <h4 class="h4"><?php the_title(); ?></h4>
            <span><?php echo implode(', ', $term_names); ?></span>
         </div>
      </div>
    </div>
    <?php
  }
}