<?php
/*
Plugin Name: Photosy Addons
Plugin URI: http://www.themebubble.com
Description: A part of Phtosy theme.
Version: 1.5
Author: themebubble
Author URI: http://www.themebubble.com
Text Domain: photosy-addons
*/
defined('PHOTOSY_ROOT') or define('PHOTOSY_ROOT', plugin_dir_path( __FILE__ ));

if(!class_exists('Photosy_Shortcode')) {

  class Photosy_Shortcode {

    private $assets_css;
    private $assets_js;

    function __construct() {
      add_action('init', array($this,'photosy_init'),50);
      add_action('setup_theme', array($this,'photosy_load_custom_post_types'),40);
      add_action('widgets_init', array($this,'photosy_load_widgets'),50);
    }

    function activate() {
      flush_rewrite_rules();
    }

    function deactivate() {
      flush_rewrite_rules();
    }

    function photosy_init() {
      if (!defined('PHOTOSY_THEME_ACTIVATED') || PHOTOSY_THEME_ACTIVATED !== true) {
        add_action( 'admin_notices', array($this,'photosy_activate_theme_notice') );
      } else {
        require_once(PHOTOSY_ROOT .'/extras/extras.php');
        $this->assets_css = plugins_url('/composer/assets/css', __FILE__);
        $this->assets_js  = plugins_url('/composer/assets/js', __FILE__);
        add_action( 'admin_print_scripts-post.php',   array($this, 'photosy_load_vc_scripts'), 99);
        add_action( 'admin_print_scripts-post-new.php', array($this, 'photosy_load_vc_scripts'), 99);
        add_action('vc_load_default_params', array($this, 'photosy_reload_vc_js'));
        if(class_exists('Vc_Manager')) {
          $this->photosy_vc_load_shortcodes();
          $this->photosy_init_vc();
          $this->photosy_vc_integration();
        }
      }
    }

    function photosy_activate_theme_notice() { ?>
      <div class="updated">
        <p><strong><?php esc_html_e('Please activate the Photosy theme to use Photosy Addons plugin.', 'photosy-addons'); ?></strong></p>
        <?php
        $screen = get_current_screen();
        if ($screen -> base != 'themes'): ?>
          <p><a href="<?php echo esc_url(admin_url('themes.php')); ?>"><?php esc_html_e('Activate theme', 'photosy-addons'); ?></a></p>
        <?php endif; ?>
      </div>
    <?php }

    function photosy_init_vc() {
      global $vc_manager;
      $list = array( 'page', 'post', 'portfolio');
      $vc_manager->setEditorDefaultPostTypes( $list );
     
    }

    function photosy_load_custom_post_types() {
      require_once(PHOTOSY_ROOT .'/custom-posts/social-site.php');
      require_once(PHOTOSY_ROOT .'/custom-posts/portfolio.php');
    }

    function photosy_load_widgets() {
      if (!defined('PHOTOSY_THEME_ACTIVATED') || PHOTOSY_THEME_ACTIVATED !== true) {
        return false;
      }
      $widgets = array(
        'WP_Latest_Posts_Widget',
        'WP_Latest_Tweets_Widget',
      );
      foreach ($widgets as $widget) {
        if (file_exists(PHOTOSY_ROOT .'/widgets/'.$widget.'.class.php')) {
          require_once(PHOTOSY_ROOT .'/widgets/'.$widget.'.class.php');
          register_widget('photosy_'.$widget);
        }
      }
    }

    function photosy_vc_load_shortcodes() {
      require_once(PHOTOSY_ROOT. '/' . 'shortcodes/photosy_portfolio_slider.php');
      require_once(PHOTOSY_ROOT. '/' . 'shortcodes/photosy_portfolio.php');
      require_once(PHOTOSY_ROOT. '/' . 'shortcodes/photosy_hero_banner.php');
      require_once(PHOTOSY_ROOT. '/' . 'shortcodes/photosy_contact_form.php');
      require_once(PHOTOSY_ROOT. '/' . 'shortcodes/photosy_about_block.php');
      require_once(PHOTOSY_ROOT. '/' . 'shortcodes/photosy_text_block_with_button.php');
      require_once(PHOTOSY_ROOT. '/' . 'shortcodes/photosy_image_block.php');
      require_once(PHOTOSY_ROOT. '/' . 'shortcodes/photosy_portfolio_project_details.php');
      require_once(PHOTOSY_ROOT. '/' . 'shortcodes/photosy_space.php');
      require_once(PHOTOSY_ROOT. '/' . 'shortcodes/photosy_special_text.php');
      require_once(PHOTOSY_ROOT. '/' . 'shortcodes/photosy_portfolio_masonry.php');
      require_once(PHOTOSY_ROOT. '/' . 'shortcodes/photosy_portfolio_grid.php');
      require_once(PHOTOSY_ROOT. '/' . 'shortcodes/photosy_instagram.php');
      require_once(PHOTOSY_ROOT. '/' . 'shortcodes/photosy_cta.php');
      require_once(PHOTOSY_ROOT. '/' . 'shortcodes/photosy_section_heading.php');
      require_once(PHOTOSY_ROOT. '/' . 'shortcodes/photosy_blog.php');
      require_once(PHOTOSY_ROOT. '/' . 'shortcodes/photosy_button.php');
      require_once(PHOTOSY_ROOT. '/' . 'shortcodes/vc_column_text.php');
    }

    function photosy_vc_integration() {
      require_once( PHOTOSY_ROOT .'/' .'composer/map.php' );
    }

    function photosy_load_vc_scripts() {
      wp_enqueue_style( 'rs-vc-custom', $this->assets_css. '/vc-style.css' );
      wp_enqueue_style( 'rs-font-icon', $this->assets_css. '/font-icon.css' );
      wp_enqueue_style( 'rs-chosen',    $this->assets_css. '/chosen.css' );
      wp_enqueue_script( 'vc-script',   $this->assets_js . '/vc-script.js' ,      array('jquery'), '1.0.0', true );
      wp_enqueue_script( 'vc-chosen',   $this->assets_js . '/jquery.chosen.js' ,  array('jquery'), '1.0.0', true );
    }

    function photosy_reload_vc_js() {
      echo '<script type="text/javascript">(function($){ $(document).ready( function(){ $.reloadPlugins(); }); })(jQuery);</script>';
    }

  } // end of class

  new Photosy_Shortcode;

} // end of class_exists


